# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .text2video_create_params import Text2videoCreateParams as Text2videoCreateParams



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.
from ...lib.utils import save_text_content
from ...lib.utils import get_current_time_string
from ..._models import BaseModel
from ..._exceptions import FileSaveError
import json

__all__ = ["WhisperResponse"]


class WhisperResponse(BaseModel):
    predictions: object

    def save(self, output_dirpath:str, filename:str=""):
        txt_data_dict = self.predictions
        if filename:
            file_name = filename
        else:
            file_name = f"WhisperLargeV3-{get_current_time_string()}-output.txt"
        try:

            save_text_content(
                json.dumps(txt_data_dict),
                output_dirpath,
                file_name,
            )

        except OSError as exc:
            raise FileSaveError(f"Exception occurred while saving output - {exc}")
        except Exception as exc:
            raise Exception(f"Exception occurred while saving output - {exc}")



import os
import logging

logger: logging.Logger = logging.getLogger("krutrim_cloud")
httpx_logger: logging.Logger = logging.getLogger("httpx")


def _basic_config() -> None:
    # e.g. [2023-10-05 14:12:26 - krutrim_cloud._base_client:818 - DEBUG] HTTP Request: POST http://127.0.0.1:4010/foo/bar "200 OK"
    logging.basicConfig(
        format="[%(asctime)s - %(name)s:%(lineno)d - %(levelname)s] %(message)s",
        datefmt="%Y-%m-%d %H:%M:%S",
    )


def setup_logging() -> None:
    env = os.environ.get("KRUTRIM_CLOUD_LOG")
    if env == "debug":
        _basic_config()
        logger.setLevel(logging.DEBUG)
        httpx_logger.setLevel(logging.DEBUG)
    elif env == "info":
        _basic_config()
        logger.setLevel(logging.INFO)
        httpx_logger.setLevel(logging.INFO)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .text2video import (
    Text2videoResource,
    AsyncText2videoResource,
    Text2videoResourceWithRawResponse,
    AsyncText2videoResourceWithRawResponse,
    Text2videoResourceWithStreamingResponse,
    AsyncText2videoResourceWithStreamingResponse,
)
from .generations import (
    GenerationsResource,
    AsyncGenerationsResource,
    GenerationsResourceWithRawResponse,
    AsyncGenerationsResourceWithRawResponse,
    GenerationsResourceWithStreamingResponse,
    AsyncGenerationsResourceWithStreamingResponse,
)

__all__ = [
    "Text2videoResource",
    "AsyncText2videoResource",
    "Text2videoResourceWithRawResponse",
    "AsyncText2videoResourceWithRawResponse",
    "Text2videoResourceWithStreamingResponse",
    "AsyncText2videoResourceWithStreamingResponse",
    "GenerationsResource",
    "AsyncGenerationsResource",
    "GenerationsResourceWithRawResponse",
    "AsyncGenerationsResourceWithRawResponse",
    "GenerationsResourceWithStreamingResponse",
    "AsyncGenerationsResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .videos import (
    VideosResource,
    AsyncVideosResource,
    VideosResourceWithRawResponse,
    AsyncVideosResourceWithRawResponse,
    VideosResourceWithStreamingResponse,
    AsyncVideosResourceWithStreamingResponse,
)
from .generations import (
    GenerationsResource,
    AsyncGenerationsResource,
    GenerationsResourceWithRawResponse,
    AsyncGenerationsResourceWithRawResponse,
    GenerationsResourceWithStreamingResponse,
    AsyncGenerationsResourceWithStreamingResponse,
)

__all__ = [
    "GenerationsResource",
    "AsyncGenerationsResource",
    "GenerationsResourceWithRawResponse",
    "AsyncGenerationsResourceWithRawResponse",
    "GenerationsResourceWithStreamingResponse",
    "AsyncGenerationsResourceWithStreamingResponse",
    "VideosResource",
    "AsyncVideosResource",
    "VideosResourceWithRawResponse",
    "AsyncVideosResourceWithRawResponse",
    "VideosResourceWithStreamingResponse",
    "AsyncVideosResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Dict, Iterable, Optional, Union, List

import httpx

from ..._types import NOT_GIVEN, Body, Query, Headers, NotGiven
from ..._utils import (
    maybe_transform,
    async_maybe_transform,
)
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ...types.chat import completion_create_params
from ..._base_client import make_request_options
from ...types.chat.completion_create_response import CompletionCreateResponse

__all__ = ["CompletionsResource", "AsyncCompletionsResource"]


class CompletionsResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> CompletionsResourceWithRawResponse:
        return CompletionsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> CompletionsResourceWithStreamingResponse:
        return CompletionsResourceWithStreamingResponse(self)

    supported_models = [
        "Krutrim-spectre-v2",
        "Mistral-7B-Instruct",
        "Meta-Llama-3-8B-Instruct",
        "Gemma-2-27B-IT",
    ]

    context_8k_models: List[str] = [
        "Mistral-7B-Instruct",
        "Meta-Llama-3-8B-Instruct",
    ]

    context_4k_models: List[str] = [
        "Krutrim-spectre-v2",
        "Gemma-2-27B-IT",
    ]

    context_128k_models: List[str] = []

    def validate_parameters(
        self,
        messages: Iterable[completion_create_params.Message] | List[Dict[str, str]],
        model: str,
        frequency_penalty: float | Union[object, None],
        logit_bias: Dict[str, int] | Union[object, None],
        logprobs: bool | Union[object, None],
        max_tokens: int | Union[object, None],
        n: int | Union[object, None],
        presence_penalty: float | Union[object, None],
        response_format: Dict[str, str] | Union[object, None],
        stop: Optional[str] | Union[object, None],
        stream: bool | Union[object, None],
        temperature: float | Union[object, None],
        top_logprobs: int | Union[object, None],
        top_p: float | Union[object, None],
        timeout: Union[float, httpx.Timeout, None, object],
        skip_special_tokens: bool | Union[object, None],
    ):
        # Validate messages
        if not isinstance(messages, list):
            raise ValueError("'messages' must be a list of dictionaries.")

        for message in messages:
            if not isinstance(message, dict):  # type: ignore
                raise ValueError("Each message in 'messages' must be a dictionary.")

            # Validate 'role' key
            if "role" not in message:
                raise ValueError("Each message dictionary must contain a 'role' key.")
            if message["role"] not in ["system", "user", "assistant"]:
                raise ValueError("The 'role' key must be one of 'system', 'user', or 'assistant'.")

            # Validate 'content' key
            if "content" not in message:
                raise ValueError("Each message dictionary must contain a 'content' key.")
            if not isinstance(message["content"], str):  # type: ignore
                raise ValueError("The 'content' key must be a string.")
            if not message["content"]:
                raise ValueError("The 'content' key cannot be empty.")

        # Validate model
        if not isinstance(model, str):  # type: ignore
            raise ValueError("'model' must be a string.")

        # Validate frequency_penalty
        if frequency_penalty is not NOT_GIVEN:
            if not isinstance(frequency_penalty, (float, int)):
                raise ValueError("'frequency_penalty' must be a float or int.")
            if isinstance(frequency_penalty, float) and not (-2.0 <= frequency_penalty <= 2.0):
                raise ValueError("'frequency_penalty' must be between -2 and 2.")
            if isinstance(frequency_penalty, int) and not (-2 <= frequency_penalty <= 2):
                raise ValueError("'frequency_penalty' must be between -2 and 2.")

        # Validate logit_bias
        if logit_bias is not NOT_GIVEN:
            if not isinstance(logit_bias, dict):
                raise ValueError("'logit_bias' must be a dictionary.")
            for key, value in logit_bias.items():  # type: ignore
                if not isinstance(key, (str, int)) or not isinstance(value, int):
                    raise ValueError("'logit_bias' keys must be strings/int and values must be integers.")

        # Validate logprobs
        if logprobs is not NOT_GIVEN:
            if not isinstance(logprobs, bool):
                raise ValueError("'logprobs' must be a boolean.")

        # Validate max_tokens
        if max_tokens is not NOT_GIVEN:
            if not isinstance(max_tokens, int):
                raise ValueError("'max_tokens' must be an integer.")
            if max_tokens <= 0:
                raise ValueError("'max_tokens' must be greater than 0.")
            if model in self.context_4k_models and max_tokens > 4096:
                raise ValueError(f"'max_tokens' must be less than 4096 for {model}.")
            if model in self.context_8k_models and max_tokens > 8192:
                raise ValueError(f"'max_tokens' must be less than 8192 for {model}.")
            if model in self.context_128k_models and max_tokens > 128000:
                raise ValueError(f"'max_tokens' must be less than 128000 for {model}.")

        # Validate n
        if n is not NOT_GIVEN:
            if not isinstance(n, int):
                raise ValueError("'n' must be an integer.")
            if n <= 0:
                raise ValueError("'n' must be greater than 0.")

        # Validate presence_penalty
        if presence_penalty is not NOT_GIVEN:
            if not isinstance(presence_penalty, (float, int)):
                raise ValueError("'presence_penalty' must be a float or int.")
            if isinstance(presence_penalty, float) and not (-2.0 <= presence_penalty <= 2.0):
                raise ValueError("'presence_penalty' must be between -2 and 2.")
            if isinstance(presence_penalty, int) and not (-2 <= presence_penalty <= 2):
                raise ValueError("'presence_penalty' must be between -2 and 2.")

        # Validate response_format
        if response_format is not NOT_GIVEN:
            if not isinstance(response_format, dict):
                raise ValueError("'response_format' must be a dictionary.")
            if "type" not in response_format or response_format["type"] not in ["text"]:
                raise ValueError("'response_format' must be a dictionary with a 'type' key set to 'text'.")

        # Validate stop
        if stop is not NOT_GIVEN:
            if not (isinstance(stop, str) or stop is None):
                raise ValueError("'stop' must be a string or None.")

        # Validate stream
        if stream is not NOT_GIVEN:
            if not isinstance(stream, bool):
                raise ValueError("'stream' must be a boolean.")

        # Validate temperature
        if temperature is not NOT_GIVEN:
            if not isinstance(temperature, (float, int)):
                raise ValueError("'temperature' must be a float/int.")
            if isinstance(temperature, float) and not (0.0 <= temperature <= 2.0):
                raise ValueError("'temperature' must be between 0 and 2.")
            if isinstance(temperature, int) and not (0 <= temperature <= 2):
                raise ValueError("'temperature' must be between 0 and 2.")

        # Validate top_logprobs
        if top_logprobs is not NOT_GIVEN:
            if not isinstance(top_logprobs, int):
                raise ValueError("'top_logprobs' must be an integer.")
            if not (0 <= top_logprobs <= 50):
                raise ValueError("'top_logprobs' must be between 0 and 50.")

        # Validate top_p
        if top_p is not NOT_GIVEN:
            if not isinstance(top_p, float):
                raise ValueError("'top_p' must be a float.")
            if not (0 < top_p <= 1):
                raise ValueError("'top_p' must be greater than 0.0 and less than and 1.0")

        # Validate timeout
        if timeout is not NOT_GIVEN:
            if not isinstance(timeout, (float, int, httpx.Timeout, type(None))):
                raise ValueError("'timeout' must be a float, int, httpx.Timeout, or None.")

        # Validate skip_special_tokens
        if skip_special_tokens is not NOT_GIVEN:
            if not isinstance(skip_special_tokens, bool):
                raise ValueError("'skip_special_tokens' must be a boolean.")

    def create(
        self,
        *,
        messages: Iterable[completion_create_params.Message] | List[Dict[str, str]],
        model: str,
        frequency_penalty: float | NotGiven = NOT_GIVEN,
        logit_bias: Dict[str, int] | NotGiven = NOT_GIVEN,
        logprobs: bool | NotGiven = NOT_GIVEN,
        max_tokens: int | NotGiven = NOT_GIVEN,
        n: int | NotGiven = NOT_GIVEN,
        presence_penalty: float | NotGiven = NOT_GIVEN,
        response_format: completion_create_params.ResponseFormat | NotGiven = NOT_GIVEN,
        stop: Optional[str] | NotGiven = NOT_GIVEN,
        stream: bool | NotGiven = NOT_GIVEN,
        temperature: float | NotGiven = NOT_GIVEN,
        top_logprobs: int | NotGiven = NOT_GIVEN,
        top_p: float | NotGiven = NOT_GIVEN,
        skip_special_tokens: bool | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> CompletionCreateResponse:
        """
        Create a chat completion

        Args:
            model: "Krutrim-spectre-v2", Supported Values are:
            "Krutrim-spectre-v2",
            "Mistral-7B-Instruct",
            "Meta-Llama-3-8B-Instruct",
            "Gemma-2-27B-IT",

            messages: [
                {
                    "role": "system",
                    "content": "You are a helpful assistant."
                },
                {
                    "role": "user",
                    "content": "Hello!"
                }
            ]

            frequency_penalty: 0, # Optional, Defaults to 0. Range: -2 to 2

            logit_bias: {2435: -100, 640: -100}

            logprobs: true, # Optional, Defaults to false

            top_logprobs: 2, # Optional. Range: 0 to 50

            max_tokens: 256, # Optional

            n: 1, # Optional, Defaults to 1

            presence_penalty: 0, # Optional, Defaults to 0. Range: -2 to 2

            response_format: { "type": "text" }, # Optional, Defaults to text

            stop: null, # Optional, Defaults to null. Can take up to 4 sequences where the API will stop generating further tokens.

            stream: false, # Optional, Defaults to false

            temperature: 0, # Optional, Defaults to 1. Range: 0 to 2

            top_p: 1 # Optional, Defaults to 1. We generally recommend altering this or temperature but not both.

            skip_special_tokens: False # Optional, Defaults to False which allows special tokens like <reflection>, <thinking>, <output> in the output text.

            extra_headers: Send extra headers

            extra_query: Add additional query parameters to the request

            extra_body: Add additional JSON properties to the request

            timeout: Override the client-level default timeout for this request, in seconds
        """

        self.validate_parameters(
            messages=messages,
            model=model,
            frequency_penalty=frequency_penalty,
            logit_bias=logit_bias,
            logprobs=logprobs,
            max_tokens=max_tokens,
            n=n,
            presence_penalty=presence_penalty,
            response_format=response_format,
            stop=stop,
            stream=stream,
            temperature=temperature,
            top_logprobs=top_logprobs,
            top_p=top_p,
            timeout=timeout,
            skip_special_tokens=skip_special_tokens,
        )

        return self._post(
            "/v1/chat/completions",
            body=maybe_transform(
                {
                    "messages": messages,
                    "model": model,
                    "frequency_penalty": frequency_penalty,
                    "logit_bias": logit_bias,
                    "logprobs": logprobs,
                    "max_tokens": max_tokens,
                    "n": n,
                    "presence_penalty": presence_penalty,
                    "response_format": response_format,
                    "stop": stop,
                    "stream": stream,
                    "temperature": temperature,
                    "top_logprobs": top_logprobs,
                    "top_p": top_p,
                    "skip_special_tokens": skip_special_tokens,
                },
                completion_create_params.CompletionCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=CompletionCreateResponse,
        )


class AsyncCompletionsResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncCompletionsResourceWithRawResponse:
        return AsyncCompletionsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncCompletionsResourceWithStreamingResponse:
        return AsyncCompletionsResourceWithStreamingResponse(self)

    supported_models = [
        "Krutrim-spectre-v2",
        "Mistral-7B-Instruct",
        "Meta-Llama-3-8B-Instruct",
        "Gemma-2-27B-IT",
    ]

    context_8k_models: List[str] = [
        "Mistral-7B-Instruct",
        "Meta-Llama-3-8B-Instruct",
    ]

    context_4k_models: List[str] = [
        "Krutrim-spectre-v2",
        "Gemma-2-27B-IT",
    ]

    context_128k_models: List[str] = []

    async def validate_parameters(
        self,
        messages: Iterable[completion_create_params.Message] | List[Dict[str, str]],
        model: str,
        frequency_penalty: float | Union[object, None],
        logit_bias: Dict[str, int] | Union[object, None],
        logprobs: bool | Union[object, None],
        max_tokens: int | Union[object, None],
        n: int | Union[object, None],
        presence_penalty: float | Union[object, None],
        response_format: Dict[str, str] | Union[object, None],
        stop: Optional[str] | Union[object, None],
        stream: bool | Union[object, None],
        temperature: float | Union[object, None],
        top_logprobs: int | Union[object, None],
        top_p: float | Union[object, None],
        timeout: Union[float, httpx.Timeout, None, object],
        skip_special_tokens: bool | Union[object, None],
    ):
        # Validate messages
        if not isinstance(messages, list):
            raise ValueError("'messages' must be a list of dictionaries.")

        for message in messages:
            if not isinstance(message, dict):  # type: ignore
                raise ValueError("Each message in 'messages' must be a dictionary.")

            # Validate 'role' key
            if "role" not in message:
                raise ValueError("Each message dictionary must contain a 'role' key.")
            if message["role"] not in ["system", "user", "assistant"]:
                raise ValueError("The 'role' key must be one of 'system', 'user', or 'assistant'.")

            # Validate 'content' key
            if "content" not in message:
                raise ValueError("Each message dictionary must contain a 'content' key.")
            if not isinstance(message["content"], str):  # type: ignore
                raise ValueError("The 'content' key must be a string.")
            if not message["content"]:
                raise ValueError("The 'content' key cannot be empty.")

        # Validate model
        if not isinstance(model, str):  # type: ignore
            raise ValueError("'model' must be a string.")

        # Validate frequency_penalty
        if frequency_penalty is not NOT_GIVEN:
            if not isinstance(frequency_penalty, (float, int)):
                raise ValueError("'frequency_penalty' must be a float or int.")
            if isinstance(frequency_penalty, float) and not (-2.0 <= frequency_penalty <= 2.0):
                raise ValueError("'frequency_penalty' must be between -2 and 2.")
            if isinstance(frequency_penalty, int) and not (-2 <= frequency_penalty <= 2):
                raise ValueError("'frequency_penalty' must be between -2 and 2.")

        # Validate logit_bias
        if logit_bias is not NOT_GIVEN:
            if not isinstance(logit_bias, dict):
                raise ValueError("'logit_bias' must be a dictionary.")
            for key, value in logit_bias.items():  # type: ignore
                if not isinstance(key, (str, int)) or not isinstance(value, int):
                    raise ValueError("'logit_bias' keys must be strings/int and values must be integers.")

        # Validate logprobs
        if logprobs is not NOT_GIVEN:
            if not isinstance(logprobs, bool):
                raise ValueError("'logprobs' must be a boolean.")

        # Validate max_tokens
        if max_tokens is not NOT_GIVEN:
            if not isinstance(max_tokens, int):
                raise ValueError("'max_tokens' must be an integer.")
            if max_tokens <= 0:
                raise ValueError("'max_tokens' must be greater than 0.")
            if model in self.context_4k_models and max_tokens > 4096:
                raise ValueError(f"'max_tokens' must be less than 4096 for {model}.")
            if model in self.context_8k_models and max_tokens > 8192:
                raise ValueError(f"'max_tokens' must be less than 8192 for {model}.")
            if model in self.context_128k_models and max_tokens > 128000:
                raise ValueError(f"'max_tokens' must be less than 128000 for {model}.")

        # Validate n
        if n is not NOT_GIVEN:
            if not isinstance(n, int):
                raise ValueError("'n' must be an integer.")
            if n <= 0:
                raise ValueError("'n' must be greater than 0.")

        # Validate presence_penalty
        if presence_penalty is not NOT_GIVEN:
            if not isinstance(presence_penalty, (float, int)):
                raise ValueError("'presence_penalty' must be a float or int.")
            if isinstance(presence_penalty, float) and not (-2.0 <= presence_penalty <= 2.0):
                raise ValueError("'presence_penalty' must be between -2 and 2.")
            if isinstance(presence_penalty, int) and not (-2 <= presence_penalty <= 2):
                raise ValueError("'presence_penalty' must be between -2 and 2.")

        # Validate response_format
        if response_format is not NOT_GIVEN:
            if not isinstance(response_format, dict):
                raise ValueError("'response_format' must be a dictionary.")
            if "type" not in response_format or response_format["type"] not in ["text"]:
                raise ValueError("'response_format' must be a dictionary with a 'type' key set to 'text'.")

        # Validate stop
        if stop is not NOT_GIVEN:
            if not (isinstance(stop, str) or stop is None):
                raise ValueError("'stop' must be a string or None.")

        # Validate stream
        if stream is not NOT_GIVEN:
            if not isinstance(stream, bool):
                raise ValueError("'stream' must be a boolean.")

        # Validate temperature
        if temperature is not NOT_GIVEN:
            if not isinstance(temperature, (float, int)):
                raise ValueError("'temperature' must be a float/int.")
            if isinstance(temperature, float) and not (0.0 <= temperature <= 2.0):
                raise ValueError("'temperature' must be between 0 and 2.")
            if isinstance(temperature, int) and not (0 <= temperature <= 2):
                raise ValueError("'temperature' must be between 0 and 2.")

        # Validate top_logprobs
        if top_logprobs is not NOT_GIVEN:
            if not isinstance(top_logprobs, int):
                raise ValueError("'top_logprobs' must be an integer.")
            if not (0 <= top_logprobs <= 50):
                raise ValueError("'top_logprobs' must be between 0 and 50.")

        # Validate top_p
        if top_p is not NOT_GIVEN:
            if not isinstance(top_p, float):
                raise ValueError("'top_p' must be a float.")
            if not (0 < top_p <= 1):
                raise ValueError("'top_p' must be greater than 0.0 and less than and 1.0")

        # Validate timeout
        if timeout is not NOT_GIVEN:
            if not isinstance(timeout, (float, int, httpx.Timeout, type(None))):
                raise ValueError("'timeout' must be a float, int, httpx.Timeout, or None.")

        # Validate skip_special_tokens
        if skip_special_tokens is not NOT_GIVEN:
            if not isinstance(skip_special_tokens, bool):
                raise ValueError("'skip_special_tokens' must be a boolean.")

    async def create(
        self,
        *,
        messages: Iterable[completion_create_params.Message],
        model: str,
        frequency_penalty: float | NotGiven = NOT_GIVEN,
        logit_bias: Dict[str, int] | NotGiven = NOT_GIVEN,
        logprobs: bool | NotGiven = NOT_GIVEN,
        max_tokens: int | NotGiven = NOT_GIVEN,
        n: int | NotGiven = NOT_GIVEN,
        presence_penalty: float | NotGiven = NOT_GIVEN,
        response_format: completion_create_params.ResponseFormat | NotGiven = NOT_GIVEN,
        stop: Optional[str] | NotGiven = NOT_GIVEN,
        stream: bool | NotGiven = NOT_GIVEN,
        temperature: float | NotGiven = NOT_GIVEN,
        top_logprobs: int | NotGiven = NOT_GIVEN,
        top_p: float | NotGiven = NOT_GIVEN,
        skip_special_tokens: bool | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> CompletionCreateResponse:
        """
        Create a chat completion

        Args:
            model: "Krutrim-spectre-v2", Supported Values are:
            "Krutrim-spectre-v2",
            "Mistral-7B-Instruct",
            "Meta-Llama-3-8B-Instruct",
            "Gemma-2-27B-IT",

            messages: [
                {
                    "role": "system",
                    "content": "You are a helpful assistant."
                },
                {
                    "role": "user",
                    "content": "Hello!"
                }
            ]

            frequency_penalty: 0, # Optional, Defaults to 0. Range: -2 to 2

            logit_bias: {2435: -100, 640: -100}

            logprobs: true, # Optional, Defaults to false

            top_logprobs: 2, # Optional. Range: 0 to 50

            max_tokens: 256, # Optional

            n: 1, # Optional, Defaults to 1

            presence_penalty: 0, # Optional, Defaults to 0. Range: -2 to 2

            response_format: { "type": "text" }, # Optional, Defaults to text

            stop: null, # Optional, Defaults to null. Can take up to 4 sequences where the API will stop generating further tokens.

            stream: false, # Optional, Defaults to false

            temperature: 0, # Optional, Defaults to 1. Range: 0 to 2

            top_p: 1 # Optional, Defaults to 1. We generally recommend altering this or temperature but not both.

            skip_special_tokens: False # Optional, Defaults to False which allows special tokens like <reflection>, <thinking>, <output> in the output text.

            extra_headers: Send extra headers

            extra_query: Add additional query parameters to the request

            extra_body: Add additional JSON properties to the request

            timeout: Override the client-level default timeout for this request, in seconds
        """
        await self.validate_parameters(
            messages=messages,
            model=model,
            frequency_penalty=frequency_penalty,
            logit_bias=logit_bias,
            logprobs=logprobs,
            max_tokens=max_tokens,
            n=n,
            presence_penalty=presence_penalty,
            response_format=response_format,
            stop=stop,
            stream=stream,
            temperature=temperature,
            top_logprobs=top_logprobs,
            top_p=top_p,
            skip_special_tokens=skip_special_tokens,
            timeout=timeout,
        )

        return await self._post(
            "/v1/chat/completions",
            body=await async_maybe_transform(
                {
                    "messages": messages,
                    "model": model,
                    "frequency_penalty": frequency_penalty,
                    "logit_bias": logit_bias,
                    "logprobs": logprobs,
                    "max_tokens": max_tokens,
                    "n": n,
                    "presence_penalty": presence_penalty,
                    "response_format": response_format,
                    "stop": stop,
                    "stream": stream,
                    "temperature": temperature,
                    "top_logprobs": top_logprobs,
                    "top_p": top_p,
                    "skip_special_tokens": skip_special_tokens,
                },
                completion_create_params.CompletionCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=CompletionCreateResponse,
        )


class CompletionsResourceWithRawResponse:
    def __init__(self, completions: CompletionsResource) -> None:
        self._completions = completions

        self.create = to_raw_response_wrapper(
            completions.create,
        )


class AsyncCompletionsResourceWithRawResponse:
    def __init__(self, completions: AsyncCompletionsResource) -> None:
        self._completions = completions

        self.create = async_to_raw_response_wrapper(
            completions.create,
        )


class CompletionsResourceWithStreamingResponse:
    def __init__(self, completions: CompletionsResource) -> None:
        self._completions = completions

        self.create = to_streamed_response_wrapper(
            completions.create,
        )


class AsyncCompletionsResourceWithStreamingResponse:
    def __init__(self, completions: AsyncCompletionsResource) -> None:
        self._completions = completions

        self.create = async_to_streamed_response_wrapper(
            completions.create,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import List, Iterable, Optional
from typing_extensions import Required, Annotated, TypedDict

from ..._utils import PropertyInfo

__all__ = ["GenerationIdeficsParams"]


class GenerationIdeficsParams(TypedDict, total=False):
    model_name: Required[Annotated[str, PropertyInfo(alias="modelName")]]

    prompts: Required[List[str]]

    images: Iterable[List[str]]

    max_tokens: Annotated[Optional[int], PropertyInfo(alias="maxTokens")]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import List, Union, Optional

import httpx

from ..._types import NOT_GIVEN, Body, Query, Headers, NotGiven
from ..._utils import (
    maybe_transform,
    async_maybe_transform,
)
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ..._base_client import make_request_options
from ...types.images import generation_diffusion_params
from ...types.images.stable_diffusion_response import StableDiffusionResponse

__all__ = ["GenerationsResource", "AsyncGenerationsResource"]


class GenerationsResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> GenerationsResourceWithRawResponse:
        return GenerationsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> GenerationsResourceWithStreamingResponse:
        return GenerationsResourceWithStreamingResponse(self)

    def validate_parameters(
        self,
        model_name: str,
        guidance_scale: float | Union[object, None],
        image_height: int,
        image_width: int,
        negative_prompt: Union[str, List[str], None] | Union[object, None],
        negative_prompt2: Union[str, List[str], None] | Union[object, None],
        num_inference_steps: int | Union[object, None],
        num_output_images: Optional[int] | Union[object, None],
        output_img_type: Optional[str] | Union[object, None],
        prompt: Union[str, List[str]] | Union[object, None],
        prompt2: Union[str, List[str], None] | Union[object, None],
        seed: Optional[int] | Union[object, None],
        timeout: Union[float, httpx.Timeout, None, object],
    ):
        # Validate model_name
        if not isinstance(model_name, str):  # type: ignore
            raise ValueError("'model_name' must be a string.")
        if not model_name:
            raise ValueError("'model_name' cannot be empty.")

        # Validate guidance_scale
        if guidance_scale is not NOT_GIVEN:
            if not isinstance(guidance_scale, (float, int)):
                raise ValueError("'guidance_scale' must be a float.")
            if not (0 < guidance_scale < 20):
                raise ValueError("'guidance_scale' must be greater than 0 and less than 20.")

        # Validate image_height
        if not isinstance(image_height, int):  # type: ignore
            raise ValueError("'image_height' must be an integer.")
        if not (256 <= image_height <= 2048):
            raise ValueError("'image_height' must be between 256 and 2048 (inclusive).")

        # Validate image_width
        if not isinstance(image_width, int):  # type: ignore
            raise ValueError("'image_width' must be an integer.")
        if not (256 <= image_width <= 2048):
            raise ValueError("'image_width' must be between 256 and 2048 (inclusive).")

        # Validate negative_prompt
        if negative_prompt is not NOT_GIVEN:
            if not isinstance(negative_prompt, (str, list)):
                raise ValueError("'negative_prompt' must be a string or a list of strings.")
            if isinstance(negative_prompt, list) and not all(
                isinstance(p, str) for p in negative_prompt  # type: ignore
            ):  # type : ignore
                raise ValueError("All items in 'negative_prompt' must be strings.")

        # Validate negative_prompt2
        if negative_prompt2 is not NOT_GIVEN:
            if not isinstance(negative_prompt2, (str, list)):
                raise ValueError("'negative_prompt2' must be a string or a list of strings.")
            if isinstance(negative_prompt2, list) and not all(
                isinstance(p, str) for p in negative_prompt2  # type: ignore
            ):
                raise ValueError("All items in 'negative_prompt2' must be strings.")

        # Validate num_inference_steps
        if num_inference_steps is not NOT_GIVEN:
            if not isinstance(num_inference_steps, int):
                raise ValueError("'num_inference_steps' must be an integer.")
            if not (1 <= num_inference_steps <= 100):
                raise ValueError("'num_inference_steps' must be between 1 and 100 (inclusive).")

        # Validate num_output_images
        if num_output_images is not NOT_GIVEN:
            if not isinstance(num_output_images, int):
                raise ValueError("'num_output_images' must be an integer.")
            if not (1 <= num_output_images <= 5):
                raise ValueError("'num_output_images' must be between 1 and 5 (inclusive).")

        # Validate output_img_type
        if output_img_type is not NOT_GIVEN:
            if output_img_type not in (None, "pil", "latent"):
                raise ValueError("'output_img_type' must be 'pil', 'latent', or None.")

        # Validate prompt
        if prompt is not NOT_GIVEN:
            if not isinstance(prompt, (str, list)):
                raise ValueError("'prompt' must be a string or a list of strings.")
            if isinstance(prompt, list) and not all(isinstance(p, str) for p in prompt):  # type: ignore
                raise ValueError("All items in 'prompt' must be strings.")

        # Validate prompt2
        if prompt2 is not NOT_GIVEN:
            if not isinstance(prompt2, (str, list)):
                raise ValueError("'prompt2' must be a string or a list of strings.")
            if isinstance(prompt2, list) and not all(isinstance(p, str) for p in prompt2):  # type: ignore
                raise ValueError("All items in 'prompt2' must be strings.")

        # Validate seed
        if seed is not NOT_GIVEN:
            if not isinstance(seed, int):
                raise ValueError("'seed' must be an integer.")
            if seed <= 0:
                raise ValueError("'seed' must be greater than 0.")

        # Validate timeout
        if timeout is not NOT_GIVEN:
            if not isinstance(timeout, (float, int, httpx.Timeout, type(None))):
                raise ValueError("'timeout' must be a float, int, httpx.Timeout, or None.")

    def diffusion(
        self,
        *,
        model_name: str,
        guidance_scale: float | NotGiven = NOT_GIVEN,
        image_height: int,
        image_width: int,
        negative_prompt: Union[str, List[str], None] | NotGiven = NOT_GIVEN,
        negative_prompt2: Union[str, List[str], None] | NotGiven = NOT_GIVEN,
        num_inference_steps: int | NotGiven = NOT_GIVEN,
        num_output_images: Optional[int] | NotGiven = NOT_GIVEN,
        output_img_type: Optional[str] | NotGiven = NOT_GIVEN,
        prompt: Union[str, List[str]],
        prompt2: Union[str, List[str], None] | NotGiven = NOT_GIVEN,
        seed: Optional[int] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> StableDiffusionResponse:
        """
        Generate Image

        Args:

            model_name: str: "diffusion1XL", # DO NOT CHANGE THIS VALUE

            prompt: str or List[str]: Specify the prompt

            prompt2: str or List[str]: Optional -  Specify any additional prompt details if required

            image_height: int: 1024, # 1024 gives the best output. Although, modify this based on your requirement. Range: 8 to 1024. Although, anything below 512 pixels won't work well

            image_width: int : 1024, # 1024 gives the best output. Although, modify this based on your requirement. Range: 8 to 1024. Although, anything below 512 pixels won't work well

            negative_prompt: str or List[str]: Optional, mention aspects (if any) to be ignored in the output image

            negative_prompt2: stror List[str]: Optional, mention aspects (if any) to be ignored in the output image

            num_output_images: int: Optional, Defaults to 1. Max value is 5.

            guidance_scale: float: Optional, Defaults to 5. Optimal values are < 15.

            num_inference_steps: int: Optional, Defaults to 50. Max value is 100.

            seed: int: Optional -  Leave it empty to generate a random value. Use the same value if you wish to get the same image. Modify the remaining parameters to get variants of the image

            output_img_type: str: Optional, Defaults to pil. Supported: pil, latent.

            extra_headers: Send extra headers

            extra_query: Add additional query parameters to the request

            extra_body: Add additional JSON properties to the request

            timeout: Override the client-level default timeout for this request, in seconds
        """

        self.validate_parameters(
            model_name=model_name,
            guidance_scale=guidance_scale,
            image_height=image_height,
            image_width=image_width,
            negative_prompt=negative_prompt,
            negative_prompt2=negative_prompt2,
            num_inference_steps=num_inference_steps,
            num_output_images=num_output_images,
            output_img_type=output_img_type,
            prompt=prompt,
            prompt2=prompt2,
            seed=seed,
            timeout=timeout,
        )

        return self._post(
            "/v1/images/generations/diffusion",
            body=maybe_transform(
                {
                    "model_name": model_name,
                    "guidance_scale": guidance_scale,
                    "image_height": image_height,
                    "image_width": image_width,
                    "negative_prompt": negative_prompt,
                    "negative_prompt2": negative_prompt2,
                    "num_inference_steps": num_inference_steps,
                    "num_output_images": num_output_images,
                    "output_img_type": output_img_type,
                    "prompt": prompt,
                    "prompt2": prompt2,
                    "seed": seed,
                },
                generation_diffusion_params.GenerationDiffusionParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=StableDiffusionResponse,
        )


class AsyncGenerationsResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncGenerationsResourceWithRawResponse:
        return AsyncGenerationsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncGenerationsResourceWithStreamingResponse:
        return AsyncGenerationsResourceWithStreamingResponse(self)

    async def validate_parameters(
        self,
        model_name: str,
        guidance_scale: float | Union[object, None],
        image_height: int,
        image_width: int,
        negative_prompt: Union[str, List[str], None] | Union[object, None],
        negative_prompt2: Union[str, List[str], None] | Union[object, None],
        num_inference_steps: int | Union[object, None],
        num_output_images: Optional[int] | Union[object, None],
        output_img_type: Optional[str] | Union[object, None],
        prompt: Union[str, List[str]] | Union[object, None],
        prompt2: Union[str, List[str], None] | Union[object, None],
        seed: Optional[int] | Union[object, None],
        timeout: Union[float, httpx.Timeout, None, object],
    ):
        # Validate model_name
        if not isinstance(model_name, str):  # type: ignore
            raise ValueError("'model_name' must be a string.")
        if not model_name:
            raise ValueError("'model_name' cannot be empty.")

        # Validate guidance_scale
        if guidance_scale is not NOT_GIVEN:
            if not isinstance(guidance_scale, (float, int)):
                raise ValueError("'guidance_scale' must be a float.")
            if not (0 < guidance_scale < 20):
                raise ValueError("'guidance_scale' must be greater than 0 and less than 20.")

        # Validate image_height
        if not isinstance(image_height, int):  # type: ignore
            raise ValueError("'image_height' must be an integer.")
        if not (256 <= image_height <= 2048):
            raise ValueError("'image_height' must be between 256 and 2048 (inclusive).")

        # Validate image_width
        if not isinstance(image_width, int):  # type: ignore
            raise ValueError("'image_width' must be an integer.")
        if not (256 <= image_width <= 2048):
            raise ValueError("'image_width' must be between 256 and 2048 (inclusive).")

        # Validate negative_prompt
        if negative_prompt is not NOT_GIVEN:
            if not isinstance(negative_prompt, (str, list)):
                raise ValueError("'negative_prompt' must be a string or a list of strings.")
            if isinstance(negative_prompt, list) and not all(
                isinstance(p, str) for p in negative_prompt  # type: ignore
            ):
                raise ValueError("All items in 'negative_prompt' must be strings.")

        # Validate negative_prompt2
        if negative_prompt2 is not NOT_GIVEN:
            if not isinstance(negative_prompt2, (str, list)):
                raise ValueError("'negative_prompt2' must be a string or a list of strings.")
            if isinstance(negative_prompt2, list) and not all(
                isinstance(p, str) for p in negative_prompt2  # type: ignore
            ):
                raise ValueError("All items in 'negative_prompt2' must be strings.")

        # Validate num_inference_steps
        if num_inference_steps is not NOT_GIVEN:
            if not isinstance(num_inference_steps, int):
                raise ValueError("'num_inference_steps' must be an integer.")
            if not (1 <= num_inference_steps <= 100):
                raise ValueError("'num_inference_steps' must be between 1 and 100 (inclusive).")

        # Validate num_output_images
        if num_output_images is not NOT_GIVEN:
            if not isinstance(num_output_images, int):
                raise ValueError("'num_output_images' must be an integer.")
            if not (1 <= num_output_images <= 5):
                raise ValueError("'num_output_images' must be between 1 and 5 (inclusive).")

        # Validate output_img_type
        if output_img_type is not NOT_GIVEN:
            if output_img_type not in (None, "pil", "latent"):
                raise ValueError("'output_img_type' must be 'pil', 'latent', or None.")

        # Validate prompt
        if prompt is not NOT_GIVEN:
            if not isinstance(prompt, (str, list)):
                raise ValueError("'prompt' must be a string or a list of strings.")
            if isinstance(prompt, list) and not all(isinstance(p, str) for p in prompt):  # type: ignore
                raise ValueError("All items in 'prompt' must be strings.")

        # Validate prompt2
        if prompt2 is not NOT_GIVEN:
            if not isinstance(prompt2, (str, list)):
                raise ValueError("'prompt2' must be a string or a list of strings.")
            if isinstance(prompt2, list) and not all(isinstance(p, str) for p in prompt2):  # type: ignore
                raise ValueError("All items in 'prompt2' must be strings.")

        # Validate seed
        if seed is not NOT_GIVEN:
            if not isinstance(seed, int):
                raise ValueError("'seed' must be an integer.")
            if seed <= 0:
                raise ValueError("'seed' must be greater than 0.")

        # Validate timeout
        if timeout is not NOT_GIVEN:
            if not isinstance(timeout, (float, int, httpx.Timeout, type(None))):
                raise ValueError("'timeout' must be a float, int, httpx.Timeout, or None.")

    async def diffusion(
        self,
        *,
        model_name: str,
        guidance_scale: float | NotGiven = NOT_GIVEN,
        image_height: int,
        image_width: int,
        negative_prompt: Union[str, List[str], None] | NotGiven = NOT_GIVEN,
        negative_prompt2: Union[str, List[str], None] | NotGiven = NOT_GIVEN,
        num_inference_steps: int | NotGiven = NOT_GIVEN,
        num_output_images: Optional[int] | NotGiven = NOT_GIVEN,
        output_img_type: Optional[str] | NotGiven = NOT_GIVEN,
        prompt: Union[str, List[str]],
        prompt2: Union[str, List[str], None] | NotGiven = NOT_GIVEN,
        seed: Optional[int] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> StableDiffusionResponse:
        """
        Generate Image

        Args:
            model_name: str: "diffusion1XL", # DO NOT CHANGE THIS VALUE

            prompt: str or List[str]: Specify the prompt

            prompt2: str or List[str]: Optional -  Specify any additional prompt details if required

            image_height: int: 1024, # 1024 gives the best output. Although, modify this based on your requirement. Range: 8 to 1024. Although, anything below 512 pixels won't work well

            image_width: int : 1024, # 1024 gives the best output. Although, modify this based on your requirement. Range: 8 to 1024. Although, anything below 512 pixels won't work well

            negative_prompt: str or List[str]: Optional, mention aspects (if any) to be ignored in the output image

            negative_prompt2: stror List[str]: Optional, mention aspects (if any) to be ignored in the output image

            num_output_images: int: Optional, Defaults to 1. Max value is 5.

            guidance_scale: float: Optional, Defaults to 5. Optimal values are < 15.

            num_inference_steps: int: Optional, Defaults to 50. Max value is 100.

            seed: int: Optional -  Leave it empty to generate a random value. Use the same value if you wish to get the same image. Modify the remaining parameters to get variants of the image

            output_img_type: str: Optional, Defaults to pil. Supported: pil, latent.

            extra_headers: Send extra headers

            extra_query: Add additional query parameters to the request

            extra_body: Add additional JSON properties to the request

            timeout: Override the client-level default timeout for this request, in seconds
        """

        await self.validate_parameters(
            model_name=model_name,
            guidance_scale=guidance_scale,
            image_height=image_height,
            image_width=image_width,
            negative_prompt=negative_prompt,
            negative_prompt2=negative_prompt2,
            num_inference_steps=num_inference_steps,
            num_output_images=num_output_images,
            output_img_type=output_img_type,
            prompt=prompt,
            prompt2=prompt2,
            seed=seed,
            timeout=timeout,
        )

        return await self._post(
            "/v1/images/generations/diffusion",
            body=await async_maybe_transform(
                {
                    "model_name": model_name,
                    "guidance_scale": guidance_scale,
                    "image_height": image_height,
                    "image_width": image_width,
                    "negative_prompt": negative_prompt,
                    "negative_prompt2": negative_prompt2,
                    "num_inference_steps": num_inference_steps,
                    "num_output_images": num_output_images,
                    "output_img_type": output_img_type,
                    "prompt": prompt,
                    "prompt2": prompt2,
                    "seed": seed,
                },
                generation_diffusion_params.GenerationDiffusionParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=StableDiffusionResponse,
        )


class GenerationsResourceWithRawResponse:
    def __init__(self, generations: GenerationsResource) -> None:
        self._generations = generations

        self.diffusion = to_raw_response_wrapper(
            generations.diffusion,
        )


class AsyncGenerationsResourceWithRawResponse:
    def __init__(self, generations: AsyncGenerationsResource) -> None:
        self._generations = generations

        self.diffusion = async_to_raw_response_wrapper(
            generations.diffusion,
        )


class GenerationsResourceWithStreamingResponse:
    def __init__(self, generations: GenerationsResource) -> None:
        self._generations = generations

        self.diffusion = to_streamed_response_wrapper(
            generations.diffusion,
        )


class AsyncGenerationsResourceWithStreamingResponse:
    def __init__(self, generations: AsyncGenerationsResource) -> None:
        self._generations = generations

        self.diffusion = async_to_streamed_response_wrapper(
            generations.diffusion,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List
from ...lib.utils import save_text_array_content
from ...lib.utils import get_current_time_string
from ..._models import BaseModel
from ..._exceptions import FileSaveError

__all__ = ["IdeficsResponse"]


class IdeficsResponse(BaseModel):
    generated_texts: List[str]

    def save(self, output_dirpath:str, filename:str=""):
        txt_data_list = self.generated_texts
        if filename:
            file_name = filename
        else:
            file_name = f"Idefics-output-{get_current_time_string()}.txt"
        try:
            save_text_array_content(txt_data_list, output_dirpath, file_name)

        except OSError as exc:
            raise FileSaveError(f"Exception occurred while saving output - {exc}")
        except Exception as exc:
            raise Exception(f"Exception occurred while saving output - {exc}")



from krutrim_cloud import KrutrimCloud
from krutrim_cloud.lib.utils import convert_audio_file_to_base64
from dotenv import load_dotenv
from pathlib import Path

load_dotenv()

client = KrutrimCloud()

try:
    # Send the base64 encoded audio data (Less than 2 minutes audio duration)
    # audio_file_path = "../resources/hindi_sample.mp3"
    # data = convert_audio_file_to_base64(audio_file_path)

    # OR
    # Send the Path object of the Audio or Video file from local storage (Video only supported as Path object, not base64 encoded string)
    data = Path("../resources/hindi_sample.mp3")  # for any duration of audio/video files

    print("Translate:")
    response = client.audio.translations.create(model_name="openai/whisper-large-v3", file=data, task="translate")

    # Access generated output
    print(f"Output: {response.predictions}")
    # OR
    # Save generated output
    response.save("./output")

    print("*" * 100)

    print("Transcribe:")
    response = client.audio.transcriptions.create(model_name="openai/whisper-large-v3", file=data, task="transcribe")
    # Access generated output
    print(f"Output: {response.predictions}")
    # OR
    # Save generated output
    response.save("./output")

except Exception as exc:
    print(f"Exception: {exc}")



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import List, Optional

import httpx

from ...._types import NOT_GIVEN, Body, Query, Headers, NotGiven
from ...._utils import (
    maybe_transform,
    async_maybe_transform,
)
from ...._compat import cached_property
from ...._resource import SyncAPIResource, AsyncAPIResource
from ...._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ...._base_client import make_request_options
from ....types.videos.generations import text2video_create_params
from ....types.videos.cog_video_response import CogVideoResponse

__all__ = ["Text2videoResource", "AsyncText2videoResource"]


class Text2videoResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> Text2videoResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return the
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/stainless-sdks/cogvideo-python#accessing-raw-response-data-eg-headers
        """
        return Text2videoResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> Text2videoResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/stainless-sdks/cogvideo-python#with_streaming_response
        """
        return Text2videoResourceWithStreamingResponse(self)

    def validate_parameters(
        self,
        model_name: str,
        prompt: List[str],
        guidance_scale: Optional[int] | NotGiven = NOT_GIVEN,
        num_frames: Optional[int] | NotGiven = NOT_GIVEN,
        num_inference_steps: Optional[int] | NotGiven = NOT_GIVEN,
        num_videos_per_prompt: Optional[int] | NotGiven = NOT_GIVEN,
    ):
        # Validate model_name
        if not isinstance(model_name, str):  # type: ignore
            raise ValueError("'model_name' must be a string.")
        if not model_name:
            raise ValueError("'model_name' cannot be empty.")

        # Validate guidance_scale
        if guidance_scale is not NOT_GIVEN:
            if not isinstance(guidance_scale, (float, int)):
                raise ValueError("'guidance_scale' must be a float.")
            if not (0 < guidance_scale < 15):
                raise ValueError("'guidance_scale' must be greater than 0 and less than 20.")

        # Validate prompt
        if not isinstance(prompt, list):
            raise ValueError("'prompt' must be a list containing a single string.")
        if len(prompt) != 1:
            raise ValueError("'prompt' must contain exactly one string.")
        if not isinstance(prompt[0], str):
            raise ValueError("The item in 'prompt' must be a string.")

        # Validate num_inference_steps
        if num_inference_steps is not NOT_GIVEN:
            if not isinstance(num_inference_steps, int):
                raise ValueError("'num_inference_steps' must be an integer.")
            if not (1 <= num_inference_steps <= 100):
                raise ValueError("'num_inference_steps' must be between 1 and 100 (inclusive).")

        # Validate num_videos_per_prompt
        if num_videos_per_prompt is not NOT_GIVEN:
            if not isinstance(num_videos_per_prompt, int):
                raise ValueError("'num_videos_per_prompt' must be an integer.")
            if num_videos_per_prompt != 1:
                raise ValueError("'num_videos_per_prompt' must be equal to 1.")

        # Validate num_frames
        if num_frames is not NOT_GIVEN:
            if not isinstance(num_frames, int):
                raise ValueError("'num_frames' must be an integer.")
            if not (10 <= num_frames <= 49):
                raise ValueError("'num_frames' must be between 10 and 49 (inclusive)")

    def create(
        self,
        *,
        model_name: str,
        prompt: List[str],
        guidance_scale: Optional[int] | NotGiven = NOT_GIVEN,
        num_frames: Optional[int] | NotGiven = NOT_GIVEN,
        num_inference_steps: Optional[int] | NotGiven = NOT_GIVEN,
        num_videos_per_prompt: Optional[int] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> CogVideoResponse:
        """
        Generate Video From Text

        Args:
            extra_headers: Send extra headers

            extra_query: Add additional query parameters to the request

            extra_body: Add additional JSON properties to the request

            timeout: Override the client-level default timeout for this request, in seconds
        """
        self.validate_parameters(
            model_name=model_name,
            prompt=prompt,
            guidance_scale=guidance_scale,
            num_frames=num_frames,
            num_inference_steps=num_inference_steps,
            num_videos_per_prompt=num_videos_per_prompt,
        )
        return self._post(
            "/v1/videos/generations/text2video",
            body=maybe_transform(
                {
                    "model_name": model_name,
                    "prompt": prompt,
                    "guidance_scale": guidance_scale,
                    "num_frames": num_frames,
                    "num_inference_steps": num_inference_steps,
                    "num_videos_per_prompt": num_videos_per_prompt,
                },
                text2video_create_params.Text2videoCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=CogVideoResponse,
        )


class AsyncText2videoResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncText2videoResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return the
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/stainless-sdks/cogvideo-python#accessing-raw-response-data-eg-headers
        """
        return AsyncText2videoResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncText2videoResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/stainless-sdks/cogvideo-python#with_streaming_response
        """
        return AsyncText2videoResourceWithStreamingResponse(self)

    async def validate_parameters(
        self,
        model_name: str,
        prompt: List[str],
        guidance_scale: Optional[int] | NotGiven = NOT_GIVEN,
        num_frames: Optional[int] | NotGiven = NOT_GIVEN,
        num_inference_steps: Optional[int] | NotGiven = NOT_GIVEN,
        num_videos_per_prompt: Optional[int] | NotGiven = NOT_GIVEN,
    ):
        # Validate model_name
        if not isinstance(model_name, str):  # type: ignore
            raise ValueError("'model_name' must be a string.")
        if not model_name:
            raise ValueError("'model_name' cannot be empty.")

        # Validate guidance_scale
        if guidance_scale is not NOT_GIVEN:
            if not isinstance(guidance_scale, (float, int)):
                raise ValueError("'guidance_scale' must be a float.")
            if not (0 < guidance_scale < 15):
                raise ValueError("'guidance_scale' must be greater than 0 and less than 20.")

        # Validate prompt
        if not isinstance(prompt, list):
            raise ValueError("'prompt' must be a list containing a single string.")
        if len(prompt) != 1:
            raise ValueError("'prompt' must contain exactly one string.")
        if not isinstance(prompt[0], str):
            raise ValueError("The item in 'prompt' must be a string.")

        # Validate num_inference_steps
        if num_inference_steps is not NOT_GIVEN:
            if not isinstance(num_inference_steps, int):
                raise ValueError("'num_inference_steps' must be an integer.")
            if not (1 <= num_inference_steps <= 100):
                raise ValueError("'num_inference_steps' must be between 1 and 100 (inclusive).")

        # Validate num_videos_per_prompt
        if num_videos_per_prompt is not NOT_GIVEN:
            if not isinstance(num_videos_per_prompt, int):
                raise ValueError("'num_videos_per_prompt' must be an integer.")
            if num_videos_per_prompt != 1:
                raise ValueError("'num_videos_per_prompt' must be equal to 1.")

        # Validate num_frames
        if num_frames is not NOT_GIVEN:
            if not isinstance(num_frames, int):
                raise ValueError("'num_frames' must be an integer.")
            if not (10 <= num_frames <= 49):
                raise ValueError("'num_frames' must be between 10 and 49 (inclusive)")

    async def create(
        self,
        *,
        model_name: str,
        prompt: List[str],
        guidance_scale: Optional[int] | NotGiven = NOT_GIVEN,
        num_frames: Optional[int] | NotGiven = NOT_GIVEN,
        num_inference_steps: Optional[int] | NotGiven = NOT_GIVEN,
        num_videos_per_prompt: Optional[int] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> CogVideoResponse:
        """
        Generate Video From Text

        Args:
            extra_headers: Send extra headers

            extra_query: Add additional query parameters to the request

            extra_body: Add additional JSON properties to the request

            timeout: Override the client-level default timeout for this request, in seconds
        """
        await self.validate_parameters(
            model_name=model_name,
            prompt=prompt,
            guidance_scale=guidance_scale,
            num_frames=num_frames,
            num_inference_steps=num_inference_steps,
            num_videos_per_prompt=num_videos_per_prompt,
        )
        return await self._post(
            "/v1/videos/generations/text2video",
            body=await async_maybe_transform(
                {
                    "model_name": model_name,
                    "prompt": prompt,
                    "guidance_scale": guidance_scale,
                    "num_frames": num_frames,
                    "num_inference_steps": num_inference_steps,
                    "num_videos_per_prompt": num_videos_per_prompt,
                },
                text2video_create_params.Text2videoCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=CogVideoResponse,
        )


class Text2videoResourceWithRawResponse:
    def __init__(self, text2video: Text2videoResource) -> None:
        self._text2video = text2video

        self.create = to_raw_response_wrapper(
            text2video.create,
        )


class AsyncText2videoResourceWithRawResponse:
    def __init__(self, text2video: AsyncText2videoResource) -> None:
        self._text2video = text2video

        self.create = async_to_raw_response_wrapper(
            text2video.create,
        )


class Text2videoResourceWithStreamingResponse:
    def __init__(self, text2video: Text2videoResource) -> None:
        self._text2video = text2video

        self.create = to_streamed_response_wrapper(
            text2video.create,
        )


class AsyncText2videoResourceWithStreamingResponse:
    def __init__(self, text2video: AsyncText2videoResource) -> None:
        self._text2video = text2video

        self.create = async_to_streamed_response_wrapper(
            text2video.create,
        )



from krutrim_cloud import KrutrimCloud
from dotenv import load_dotenv
import os

load_dotenv()

client = KrutrimCloud().deploy

bucket_name = "<your-bucket-name>"  # "my-bucket-name"
model_id = "<your-model-name>"  # "my_model_name"
version = "<model-version>"  # "v1" <- without '.' in version string

try:
    s3_path = f"s3://{bucket_name}/{model_id}/{version}"
    deploy_response = client.tasks.create(
        model=model_id,
        path=s3_path,
        s3_endpoint=os.environ.get("KRUTRIM_CLOUD_S3_BUCKET_ENDPOINT"),  # type: ignore
        s3_access_key=os.environ.get("KRUTRIM_CLOUD_S3_PUBLIC_KEY"),  # type: ignore
        s3_secret=os.environ.get("KRUTRIM_CLOUD_S3_SECRET_KEY"),  # type: ignore
        s3_region=os.environ.get("KRUTRIM_CLOUD_S3_REGION"),
    )
    deploy_model_name = deploy_response.name
    deploy_task_id = deploy_response.id

    print(f"Deployed Model Name: {deploy_model_name}")
    print(f"Deploy Task ID: {deploy_task_id}")

    retrieve_response = client.tasks.retrieve(id=deploy_task_id)  # type: ignore
    print(f"Deploy Task Status: {retrieve_response.status}")
    print("*" * 100)

    task_list = client.tasks.list().task_list
    for task in task_list:
        print(f"Task ID: {task['id']} | Status: {task['status']}")

    # Cancel Task
    client.tasks.cancel(deploy_task_id)

except Exception as exc:
    print(f"Exception: {exc}")



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import TypedDict

__all__ = ["TaskCreateParams"]


class TaskCreateParams(TypedDict, total=False):

    argument: str
    """additional argument to parse to inference engine"""

    checkpoint: str
    """Checkpoint name."""

    max_batch_size: int
    """max batch size"""

    max_replicas: int
    """Max number of replicas"""

    min_replicas: int
    """Min number of replicas"""

    model: str
    """Model name."""

    namespace: str
    """Task Name."""

    ngpu: int
    """Number of GPU to be used by the inference task."""

    path: str
    """Checkpoint path."""

    priority: int
    """Task priority."""

    region: str
    """Region Name"""

    s3_access_key: str
    """S3 access key"""

    s3_endpoint: str
    """S3 endpoint"""

    s3_region: str
    """S3 region"""

    s3_secret: str
    """S3 secret"""



import base64
from PIL import Image
import io
import os
import cv2
import numpy as np
from datetime import datetime
from krutrim_cloud._exceptions import TimeRetrievalError, CouldNotDecodeError
from pydub import AudioSegment  # type: ignore
from pydub.exceptions import CouldntDecodeError  # type: ignore
from moviepy.editor import ImageSequenceClip


def convert_base64_to_PIL_img(base64_data: str) -> Image.Image:
    """
    Convert a base64 encoded string to a PIL Image.

    Args:
        base64_data (str): A base64 encoded string representing image data.

    Returns:
        PIL.Image.Image: A PIL Image object created from the base64 encoded data.

    Raises:
        ValueError: If the base64_data is not a valid base64 string.
        IOError: If the base64 data cannot be decoded into an image.

    Example:
        >>> base64_data = "iVBORw0KGgoAAAANSUhEUgAAAAUA..."
        >>> image = convert_base64_to_PIL_img(base64_data)
        >>> image.show()
    """
    try:
        img_bytes = base64.b64decode(base64_data)
    except (base64.binascii.Error, TypeError) as e:
        raise ValueError("Invalid base64 string") from e

    try:
        image = Image.open(io.BytesIO(img_bytes))
    except (IOError, ValueError) as e:
        raise IOError("Cannot convert base64 data to an image") from e

    return image


def convert_base64_to_OpenCV_img(base64_str: str):
    """
    Convert a base64 string to an OpenCV image.

    Args:
        base64_str (str): The base64 string of the image

    Returns:
        An OpenCV image (NumPy array)
    """
    try:
        # Decode the base64 string to binary data
        image_data = base64.b64decode(base64_str)
    except base64.binascii.Error as e:
        raise ValueError("Invalid base64 string") from e

    try:
        # Convert the binary data to a NumPy array
        np_arr = np.frombuffer(image_data, np.uint8)

        # Check if the conversion to a NumPy array was successful
        if np_arr.size == 0:
            raise CouldNotDecodeError("Error: The decoded data could not be converted to a NumPy array.")

        # Decode the NumPy array into an OpenCV image
        opencv_image = cv2.imdecode(np_arr, cv2.IMREAD_COLOR)

        # Check if the decoding was successful
        if opencv_image is None:
            raise CouldNotDecodeError("Error: The NumPy array could not be decoded into an OpenCV image.")

    except Exception as e:
        raise Exception(f"An error occurred while converting the base64 data to an OpenCV image: {e}")

    return opencv_image


def save_PIL_img(PIL_image_obj: Image.Image, output_dirpath: str, filename: str) -> None:
    """
    Save a PIL Image object to the specified directory with the given filename.

    Args:
        PIL_image_obj (PIL.Image.Image): The PIL Image object to be saved.
        output_dirpath (str): The directory path where the image will be saved.
        filename (str): The name of the file to save the image as.

    Returns:
        None

    Raises:
        ValueError: If the PIL_image_obj is not a valid PIL Image object.
        OSError: If the image cannot be saved due to an OS-related error.

    Example:
        >>> from PIL import Image
        >>> image = Image.new('RGB', (100, 100), color = 'red')
        >>> save_PIL_img(image, '/path/to/save', 'image.png')
    """
    if not isinstance(PIL_image_obj, Image.Image):
        raise ValueError("The provided object is not a valid PIL Image object.")

    try:
        os.makedirs(output_dirpath, exist_ok=True)
    except OSError as e:
        raise OSError(f"Failed to create directory '{output_dirpath}': {e}")

    try:
        save_path = os.path.join(output_dirpath, filename)
        PIL_image_obj.save(save_path)
    except OSError as e:
        raise OSError(f"Failed to save the image to '{save_path}': {e}")


def save_text_array_content(text_data_array: list, output_dirpath: str, filename: str) -> None:
    """
    Save the content of a list of text data to a file in the specified directory.

    Args:
        text_data_array (list): A list of strings where each string represents a line of text.
        output_dirpath (str): The directory path where the file will be saved.
        filename (str): The name of the file to save the text data as.

    Returns:
        None

    Raises:
        ValueError: If text_data_array is not a list of strings.
        OSError: If the directory cannot be created or the file cannot be written due to an OS-related error.

    Example:
        >>> text_data = ["Line 1", "Line 2", "Line 3"]
        >>> save_text_array_content(text_data, '/path/to/save', 'output.txt')
    """
    if not isinstance(text_data_array, list) or not all(isinstance(line, str) for line in text_data_array):
        raise ValueError("text_data_array must be a list of strings.")

    try:
        os.makedirs(output_dirpath, exist_ok=True)
    except OSError as e:
        raise OSError(f"Failed to create directory '{output_dirpath}': {e}")

    try:
        file_path = os.path.join(output_dirpath, filename)
        with open(file_path, "w") as file:
            for line in text_data_array:
                file.write(line + "\n")
    except OSError as e:
        raise OSError(f"Failed to write to file '{file_path}': {e}")


def save_text_content(text_data: str, output_dirpath: str, filename: str) -> None:
    """
    Save a string of text data to a file in the specified directory.

    Args:
        text_data (str): The text data to be saved to the file.
        output_dirpath (str): The directory path where the file will be saved.
        filename (str): The name of the file to save the text data as.

    Returns:
        None

    Raises:
        ValueError: If text_data is not a string.
        OSError: If the directory cannot be created or the file cannot be written due to an OS-related error.

    Example:
        >>> text_data = "This is a sample text."
        >>> save_text_content(text_data, '/path/to/save', 'output.txt')
    """
    if not isinstance(text_data, str):
        raise ValueError("text_data must be a string.")

    try:
        os.makedirs(output_dirpath, exist_ok=True)
    except OSError as e:
        raise OSError(f"Failed to create directory '{output_dirpath}': {e}")

    try:
        file_path = os.path.join(output_dirpath, filename)
        with open(file_path, "w") as file:
            file.write(text_data + "\n")
    except OSError as e:
        raise OSError(f"Failed to write to file '{file_path}': {e}")


def convert_PIL_image_to_base64(PIL_image_obj: Image.Image, format: str = "JPEG") -> str:
    """
    Convert a PIL Image object to a base64 encoded string.

    Args:
        PIL_image_obj (PIL.Image.Image): The PIL Image object to be converted.
        format (str): The format to use for encoding the image. Defaults to "JPEG".

    Returns:
        str: The base64 encoded string of the image.

    Raises:
        ValueError: If PIL_image_obj is not a valid PIL Image object.
        OSError: If there is an error during the image saving or encoding process.

    Example:
        >>> from PIL import Image
        >>> image = Image.new('RGB', (100, 100), color = 'red')
        >>> base64_string = convert_PIL_image_to_base64(image, format="PNG")
        >>> print(base64_string)
    """
    if not isinstance(PIL_image_obj, Image.Image):
        raise ValueError("The provided object is not a valid PIL Image object.")

    try:
        # Convert the PIL Image to a BytesIO object
        buffered = io.BytesIO()
        PIL_image_obj.save(buffered, format=format)
    except (OSError, ValueError) as e:
        raise OSError(f"Failed to save the image to a BytesIO object: {e}")

    try:
        # Encode the BytesIO object to base64
        return base64.b64encode(buffered.getvalue()).decode("utf-8")
    except (base64.binascii.Error, TypeError) as e:
        raise OSError(f"Failed to encode the image to base64: {e}")


def validate_audio_file(file_path: str) -> bool:
    """
    Validates whether the input file is a valid audio file.

    Parameters:
    -----------
    file_path : str
        The path to the audio file to be validated.

    Returns:
    --------
    bool
        True if the file is a valid audio file, False otherwise.

    Raises:
    -------
    FileNotFoundError:
        If the input audio file does not exist.
    """
    try:
        # Attempt to load the file using pydub
        _ = AudioSegment.from_file(file_path)  # type: ignore
        return True

    except FileNotFoundError:
        raise  # Re-raise the exception to handle it in the calling context

    except CouldntDecodeError:
        raise  # Re-raise the exception to handle it in the calling context

    except Exception:
        raise  # Re-raise the exception to handle it in the calling context


def convert_audio_file_to_base64(audio_filepath: str) -> str:
    """
    Convert an audio file to a base64 encoded string.

    Args:
        audio_filepath (str): The file path to the audio file to be converted.

    Returns:
        str: The base64 encoded string of the audio file.

    Raises:
        FileNotFoundError: If the audio file does not exist.
        OSError: If there is an error reading the audio file.
        ValueError: If audio_filepath is not a valid string.

    Example:
        >>> base64_string = convert_audio_file_to_base64('/path/to/audio.mp3')
        >>> print(base64_string)
    """
    if not isinstance(audio_filepath, str):
        raise ValueError("audio_filepath must be a valid string.")

    try:
        if validate_audio_file(audio_filepath):
            with open(audio_filepath, "rb") as audio_file:
                audio_data = audio_file.read()
    except FileNotFoundError as e:
        raise FileNotFoundError(f"Audio file '{audio_filepath}' not found: {e}")
    except OSError as e:
        raise OSError(f"Error reading the audio file '{audio_filepath}': {e}")
    except CouldntDecodeError as decode_error:
        raise CouldntDecodeError(
            f"The file '{audio_filepath}' is not a valid or supported audio file format.\n{decode_error}"
        )
    try:
        # Encode the audio data to base64
        return base64.b64encode(audio_data).decode("utf-8")
    except (base64.binascii.Error, TypeError) as e:
        raise ValueError(f"Failed to encode the audio file to base64: {e}")


def get_current_time_string(format: str = "%Y%m%d_%H%M%S") -> str:
    """
    Retrieve the current time as a string in the specified format.

    Args:
        format (str): The format in which to return the current time string. Defaults to "%Y%m%d_%H%M%S".

    Returns:
        str: The current time formatted as a string.

    Raises:
        TimeRetrievalError: If there's an issue retrieving or formatting the current time.

    Example:
        >>> current_time = get_current_time_string()
        >>> print(current_time)  # Output: 20240801_130501
    """
    try:
        current_time = datetime.now()
        time_string = current_time.strftime(format)
        return time_string
    except Exception as exc:
        raise TimeRetrievalError(f"Failed to retrieve or format the current time: {exc}")


def create_video_clip(video_frames, fps=8):
    """
    Create a video clip from a list of video frames.

    Args:
        video_frames (list): A list of frames, each represented as an image object (e.g., PIL Image or similar).
        fps (int, optional): Frames per second for the video. Defaults to 8.

    Returns:
        ImageSequenceClip: A MoviePy ImageSequenceClip object created from the provided frames.

    Raises:
        ValueError: If any frame in video_frames cannot be converted to a numpy array.
        TypeError: If video_frames is not a list or contains non-image objects.

    Example:
        >>> video_frames = [frame1, frame2, frame3]
        >>> clip = create_video_clip(video_frames, fps=10)
        >>> clip.write_videofile("output_video.mp4")
    """
    try:
        frames = [np.array(frame) for frame in video_frames]
    except Exception as e:
        raise ValueError("Error converting frames to numpy arrays") from e
    try:
        clip = ImageSequenceClip(frames, fps=fps)
    except Exception as e:
        raise ValueError("Error creating video clip from frames") from e
    return clip


def save_video_clip(video_frames, output_dirpath: str, filename: str, fps=8) -> None:
    """
    Create a video clip from the provided frames and save it to the specified directory with the given filename.

    Args:
        video_frames (list): A list of frames, each represented as an image object (e.g., PIL Image or similar).
        output_dirpath (str): The directory path where the video will be saved.
        filename (str): The name of the file to save the video as.
        fps (int, optional): Frames per second for the video. Defaults to 8.

    Returns:
        None

    Raises:
        ValueError: If the video_frames cannot be converted to a video clip.
        OSError: If the video cannot be saved due to an OS-related error.

    Example:
        >>> video_frames = [frame1, frame2, frame3]
        >>> save_video_clip(video_frames, '/path/to/save', 'video.mp4')
    """
    try:
        clip = create_video_clip(video_frames, fps)
    except ValueError as e:
        raise ValueError("Error creating video clip") from e
    try:
        os.makedirs(output_dirpath, exist_ok=True)
    except OSError as e:
        raise OSError(f"Failed to create directory '{output_dirpath}': {e}")
    try:
        save_path = os.path.join(output_dirpath, filename)
        clip.write_videofile(save_path, fps=fps)
    except OSError as e:
        raise OSError(f"Failed to save the video to '{save_path}': {e}")



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .tasks import (
    TasksResource,
    AsyncTasksResource,
    TasksResourceWithRawResponse,
    AsyncTasksResourceWithRawResponse,
    TasksResourceWithStreamingResponse,
    AsyncTasksResourceWithStreamingResponse,
)
from .deploy import (
    DeployResource,
    AsyncDeployResource,
    DeployResourceWithRawResponse,
    AsyncDeployResourceWithRawResponse,
    DeployResourceWithStreamingResponse,
    AsyncDeployResourceWithStreamingResponse,
)

__all__ = [
    "TasksResource",
    "AsyncTasksResource",
    "TasksResourceWithRawResponse",
    "AsyncTasksResourceWithRawResponse",
    "TasksResourceWithStreamingResponse",
    "AsyncTasksResourceWithStreamingResponse",
    "DeployResource",
    "AsyncDeployResource",
    "DeployResourceWithRawResponse",
    "AsyncDeployResourceWithRawResponse",
    "DeployResourceWithStreamingResponse",
    "AsyncDeployResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional, Union, Dict, Any, List

import httpx

from ..._types import NOT_GIVEN, Body, Query, Headers, NotGiven
from ..._utils import (
    maybe_transform,
    async_maybe_transform,
)
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ...types.audio import transcription_create_params
from ..._base_client import make_request_options
from ...types.shared.whisper_response import WhisperResponse
from ...lib.utils import convert_audio_file_to_base64
from pathlib import Path
from pydub import AudioSegment  # type: ignore
from pydub.exceptions import CouldntDecodeError  # type: ignore
from os import sep
import shutil

__all__ = ["TranscriptionsResource", "AsyncTranscriptionsResource"]


class TranscriptionsResource(SyncAPIResource):
    tmp_path = Path("./tmp_audio_store")
    tmp_filename_prefix = "audio-chunk"

    @cached_property
    def with_raw_response(self) -> TranscriptionsResourceWithRawResponse:
        return TranscriptionsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> TranscriptionsResourceWithStreamingResponse:
        return TranscriptionsResourceWithStreamingResponse(self)

    def validate_parameters(
        self,
        chunk_type: Optional[str] | Union[object, None],
        file: str | Path | AudioSegment | Union[object, None],
        language: Optional[str] | Union[object, None],
        model_name: str | Union[object, None],
        response_format: Optional[str] | Union[object, None],
        task: str | Union[object, None],
        temperature: Optional[float] | Union[object, None],
        timeout: Union[float, httpx.Timeout, None, object],
    ):
        # Validate chunk_type
        if chunk_type is not NOT_GIVEN:
            if chunk_type not in (None, "sentence", "word"):
                raise ValueError("'chunk_type' must be 'sentence', 'word', or None.")

        # Validate file
        if file is not NOT_GIVEN:
            if not isinstance(file, (str, Path, AudioSegment)):
                raise ValueError(
                    "'file' must be a string or Path object from pathlib or AudioSegment object from pydub."
                )
            if not file:
                raise ValueError("'file' cannot be empty or None.")

        # Validate language
        if language is not NOT_GIVEN:
            if not isinstance(language, str) and language is not None:
                raise ValueError("'language' must be a string or None.")
            if language:
                language = str(language).lower()
        else:
            language = "english"

        # Validate model_name
        if model_name is not NOT_GIVEN:
            if not isinstance(model_name, str):
                raise ValueError("'model_name' must be a string.")
            if not model_name:
                raise ValueError("'model_name' cannot be empty.")

        # Validate response_format
        if response_format is not NOT_GIVEN:
            if response_format not in (None, "json", "verbose_json"):
                raise ValueError("'response_format' must be 'json', 'verbose_json', or None.")

        # Validate task
        if task is not NOT_GIVEN:
            if not isinstance(task, str):
                raise ValueError("'task' must be a string.")
            if not task:
                raise ValueError("'task' cannot be empty.")

        # Validate temperature
        if temperature is not NOT_GIVEN:
            if not isinstance(temperature, (float, int)) and temperature is not None:
                raise ValueError("'temperature' must be a float or None.")
            if isinstance(temperature, float) and not (0.0 <= temperature <= 2.0):
                raise ValueError("'temperature' must be between 0.0 and 2.0.")
            if isinstance(temperature, int) and not (0 <= temperature <= 2):
                raise ValueError("'temperature' must be between 0.0 and 2.0.")

        # Validate timeout
        if timeout is not NOT_GIVEN:
            if not isinstance(timeout, (float, int, httpx.Timeout, type(None))):
                raise ValueError("'timeout' must be a float, int, httpx.Timeout, or None.")

        return language

    def _send_post_request(self, payload: Dict[str, Any], extra_options: Dict[str, Any]):
        return self._post(
            "/v1/audio/transcriptions",
            body=maybe_transform(
                payload,
                transcription_create_params.TranscriptionCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_options["extra_headers"],
                extra_query=extra_options["extra_query"],
                extra_body=extra_options["extra_body"],
                timeout=extra_options["timeout"],
            ),
            cast_to=WhisperResponse,
        )

    def _merge_predictions(self, dicts: List[Dict[str, Any]]) -> Dict[str, Any]:
        """
        Merges a list of predictions that contain `text` and `chunks`(if present) keys.

        This function combines the `text` values from each prediction into a single string,
        separated by spaces. It also merges the `chunks` lists from each prediction into a
        single list, preserving the order of chunks as they appear in the input dictionaries.

        Parameters:
        -----------
        dicts : List[Dict[str, Any]]
            A list of predictions to be merged. Each prediction should contain the keys
            'text' (a string) and 'chunks' (a list of dictionaries with `timestamp` and `text`).

        Returns:
        --------
        Dict[str, Any]
            A single dictionary with the merged `text` and `chunks` values.

        Example:
        --------
        >>> dict_1 = {
        ...     "text": "Hello, this is the first text.",
        ...     "chunks": [
        ...         {"timestamp": [0.0, 3.0], "text": "Hello, this"},
        ...         {"timestamp": [3.0, 7.0], "text": "is the first text."}
        ...     ]
        ... }
        >>> dict_2 = {
        ...     "text": "And here is the second text.",
        ...     "chunks": [
        ...         {"timestamp": [0.0, 4.0], "text": "And here"},
        ...         {"timestamp": [4.0, 8.0], "text": "is the second text."}
        ...     ]
        ... }
        >>> _merge_predictions([dict_1, dict_2])
        {
            'text': 'Hello, this is the first text. And here is the second text.',
            'chunks': [
                {"timestamp": [0.0, 3.0], "text": "Hello, this"},
                {"timestamp": [3.0, 7.0], "text": "is the first text."},
                {"timestamp": [0.0, 4.0], "text": "And here"},
                {"timestamp": [4.0, 8.0], "text": "is the second text."}
            ]
        }
        """
        merged_dict: Dict[str, Any]

        if "chunks" in dicts[0]:
            merged_dict = {"text": "", "chunks": []}
        else:
            merged_dict = {"text": ""}

        for data_dict in dicts:
            # Ensure that the current dictionary has the expected keys
            if "text" in data_dict:
                merged_dict["text"] += data_dict.get("text", "") + " "
            if "chunks" in data_dict:
                merged_dict["chunks"].extend(data_dict.get("chunks", []))

        # Clean up the trailing space in the merged 'text'
        merged_dict["text"] = merged_dict["text"].strip()

        return merged_dict

    def create(
        self,
        *,
        chunk_type: Optional[str] | NotGiven = NOT_GIVEN,
        file: str | Path | NotGiven = NOT_GIVEN,
        language: Optional[str] | NotGiven = NOT_GIVEN,
        model_name: str | NotGiven = NOT_GIVEN,
        response_format: Optional[str] | NotGiven = NOT_GIVEN,
        task: str | NotGiven = NOT_GIVEN,
        temperature: Optional[float] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> WhisperResponse:  # type: ignore
        """
        Generate Audio Transcription

        Args:
            file:"<your base64 encoded audio byte data here>" OR "Path object of pathlib for the audio filepath"

            model_name: "openai/whisper-large-v3", # DO NOT CHANGE this

            task: "transcribe",

            language: "hindi", # Source language of the audio

            temperature: 0.0, # Optional, defaults to 0.0. Range - 0.0 to 2.0

            response_format: "json", # Optional, defaults to json. Values - verbose_json (or) json

            chunk_type: "word" # Optional, defaults to sentence. Values - sentence (or) word

            extra_headers: Send extra headers

            extra_query: Add additional query parameters to the request

            extra_body: Add additional JSON properties to the request

            timeout: Override the client-level default timeout for this request, in seconds
        """
        language = str(
            self.validate_parameters(
                chunk_type=chunk_type,
                file=file,
                language=language,
                model_name=model_name,
                response_format=response_format,
                task=task,
                temperature=temperature,
                timeout=timeout,
            )
        )
        payload = {
            "chunk_type": chunk_type,
            "file": file,
            "language": language,
            "model_name": model_name,
            "response_format": response_format,
            "task": task,
            "temperature": temperature,
        }

        extra_options = {
            "extra_headers": extra_headers,
            "extra_query": extra_query,
            "extra_body": extra_body,
            "timeout": timeout,
        }
        tmp_filepath = None

        if isinstance(file, str):
            return self._send_post_request(payload, extra_options)
        elif isinstance(file, Path) or isinstance(file, AudioSegment):
            try:
                if isinstance(file, Path):
                    audio_data = AudioSegment.from_file(file)  # type: ignore
                else:
                    audio_data = file  # type: ignore
                audio_data_duration: float = audio_data.duration_seconds  # type: ignore

                Path.mkdir(self.tmp_path, exist_ok=True)
                tmp_filepath = f"{self.tmp_path.as_posix()}{sep}{self.tmp_filename_prefix}.mp3"
                if audio_data_duration <= 120.0:  # Less then or equal to 2 minutes audio
                    with open(tmp_filepath, "wb") as file_object:
                        audio_data.export(file_object, format="mp3")  # type: ignore

                    audio_b64_data = convert_audio_file_to_base64(tmp_filepath)
                    payload["file"] = audio_b64_data
                    shutil.rmtree(self.tmp_path.as_posix())
                    return self._send_post_request(payload, extra_options)
                else:
                    audio_data_chunks = audio_data[::120000]  # type: ignore # chunking with interval of 120 seconds
                    predictions: List[Dict[str, Any]] = []
                    for index, audio_data_chunk in enumerate(audio_data_chunks):  # type: ignore
                        tmp_filepath = f"{self.tmp_path.as_posix()}{sep}{self.tmp_filename_prefix}-{index}.mp3"
                        with open(tmp_filepath, "wb") as f:
                            audio_data_chunk.export(f, format="mp3")  # type: ignore

                        audio_b64_data = convert_audio_file_to_base64(tmp_filepath)
                        payload["file"] = audio_b64_data
                        predictions.append(self._send_post_request(payload, extra_options).predictions)  # type: ignore
                    shutil.rmtree(self.tmp_path.as_posix())
                    whisperResponse = WhisperResponse(predictions=None)
                    whisperResponse.predictions = self._merge_predictions(predictions)
                    return whisperResponse
            except CouldntDecodeError as decode_error:
                if isinstance(file, Path):
                    raise CouldntDecodeError(
                        f"The file '{file.as_posix()}' is not a valid or supported audio file format.\n{decode_error}"
                    )
                else:
                    raise CouldntDecodeError(f"The file is not a valid or supported audio file format.\n{decode_error}")
            except FileNotFoundError as fnf_error:
                raise FileNotFoundError(f"Error: The file '{tmp_filepath}' was not found. {fnf_error}")

            except ValueError as val_error:
                raise ValueError(f"{val_error}")

            except Exception as exc:
                raise Exception(exc)


class AsyncTranscriptionsResource(AsyncAPIResource):
    tmp_path = Path("./tmp_audio_store")
    tmp_filename_prefix = "audio-chunk"

    @cached_property
    def with_raw_response(self) -> AsyncTranscriptionsResourceWithRawResponse:
        return AsyncTranscriptionsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncTranscriptionsResourceWithStreamingResponse:
        return AsyncTranscriptionsResourceWithStreamingResponse(self)

    async def validate_parameters(
        self,
        chunk_type: Optional[str] | Union[object, None],
        file: str | Path | AudioSegment | Union[object, None],
        language: Optional[str] | Union[object, None],
        model_name: str | Union[object, None],
        response_format: Optional[str] | Union[object, None],
        task: str | Union[object, None],
        temperature: Optional[float] | Union[object, None],
        timeout: Union[float, httpx.Timeout, None, object],
    ):
        # Validate chunk_type
        if chunk_type is not NOT_GIVEN:
            if chunk_type not in (None, "sentence", "word"):
                raise ValueError("'chunk_type' must be 'sentence', 'word', or None.")

        # Validate file
        if file is not NOT_GIVEN:
            if not isinstance(file, (str, Path, AudioSegment)):
                raise ValueError(
                    "'file' must be a string or Path object from pathlib or AudioSegment object from pydub."
                )
            if not file:
                raise ValueError("'file' cannot be empty or None.")

        # Validate language
        if language is not NOT_GIVEN:
            if not isinstance(language, str) and language is not None:
                raise ValueError("'language' must be a string or None.")
            if language:
                language = str(language).lower()
        else:
            language = "english"

        # Validate model_name
        if model_name is not NOT_GIVEN:
            if not isinstance(model_name, str):
                raise ValueError("'model_name' must be a string.")
            if not model_name:
                raise ValueError("'model_name' cannot be empty.")

        # Validate response_format
        if response_format is not NOT_GIVEN:
            if response_format not in (None, "json", "verbose_json"):
                raise ValueError("'response_format' must be 'json', 'verbose_json', or None.")

        # Validate task
        if task is not NOT_GIVEN:
            if not isinstance(task, str):
                raise ValueError("'task' must be a string.")
            if not task:
                raise ValueError("'task' cannot be empty.")

        # Validate temperature
        if temperature is not NOT_GIVEN:
            if not isinstance(temperature, (float, int)) and temperature is not None:
                raise ValueError("'temperature' must be a float or None.")
            if isinstance(temperature, float) and not (0.0 <= temperature <= 2.0):
                raise ValueError("'temperature' must be between 0.0 and 2.0.")
            if isinstance(temperature, int) and not (0 <= temperature <= 2):
                raise ValueError("'temperature' must be between 0.0 and 2.0.")

        # Validate timeout
        if timeout is not NOT_GIVEN:
            if not isinstance(timeout, (float, int, httpx.Timeout, type(None))):
                raise ValueError("'timeout' must be a float, int, httpx.Timeout, or None.")

        return language

    async def _send_post_request(self, payload: Dict[str, Any], extra_options: Dict[str, Any]):
        return await self._post(
            "/v1/audio/transcriptions",
            body=await async_maybe_transform(
                payload,
                transcription_create_params.TranscriptionCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_options["extra_headers"],
                extra_query=extra_options["extra_query"],
                extra_body=extra_options["extra_body"],
                timeout=extra_options["timeout"],
            ),
            cast_to=WhisperResponse,
        )

    async def _merge_predictions(self, dicts: List[Dict[str, Any]]) -> Dict[str, Any]:
        """
        Merges a list of dictionaries that contain `text` and `chunks`(if present) keys.

        This function combines the `text` values from each dictionary into a single string,
        separated by spaces. It also merges the `chunks` lists from each dictionary into a
        single list, preserving the order of chunks as they appear in the input dictionaries.

        Parameters:
        -----------
        dicts : List[Dict[str, Any]]
            A list of dictionaries to be merged. Each dictionary should contain the keys
            'text' (a string) and 'chunks' (a list of dictionaries with `timestamp` and `text`).

        Returns:
        --------
        Dict[str, Any]
            A single dictionary with the merged `text` and `chunks` values.

        Example:
        --------
        >>> dict_1 = {
        ...     "text": "Hello, this is the first text.",
        ...     "chunks": [
        ...         {"timestamp": [0.0, 3.0], "text": "Hello, this"},
        ...         {"timestamp": [3.0, 7.0], "text": "is the first text."}
        ...     ]
        ... }
        >>> dict_2 = {
        ...     "text": "And here is the second text.",
        ...     "chunks": [
        ...         {"timestamp": [0.0, 4.0], "text": "And here"},
        ...         {"timestamp": [4.0, 8.0], "text": "is the second text."}
        ...     ]
        ... }
        >>> _merge_predictions([dict_1, dict_2])
        {
            'text': 'Hello, this is the first text. And here is the second text.',
            'chunks': [
                {"timestamp": [0.0, 3.0], "text": "Hello, this"},
                {"timestamp": [3.0, 7.0], "text": "is the first text."},
                {"timestamp": [0.0, 4.0], "text": "And here"},
                {"timestamp": [4.0, 8.0], "text": "is the second text."}
            ]
        }
        """
        merged_dict: Dict[str, Any]

        if "chunks" in dicts[0]:
            merged_dict = {"text": "", "chunks": []}
        else:
            merged_dict = {"text": ""}

        for data_dict in dicts:
            # Ensure that the current dictionary has the expected keys
            if "text" in data_dict:
                merged_dict["text"] += data_dict.get("text", "") + " "
            if "chunks" in data_dict:
                merged_dict["chunks"].extend(data_dict.get("chunks", []))

        # Clean up the trailing space in the merged 'text'
        merged_dict["text"] = merged_dict["text"].strip()

        return merged_dict

    async def create(
        self,
        *,
        chunk_type: Optional[str] | NotGiven = NOT_GIVEN,
        file: str | Path | NotGiven = NOT_GIVEN,
        language: Optional[str] | NotGiven = NOT_GIVEN,
        model_name: str | NotGiven = NOT_GIVEN,
        response_format: Optional[str] | NotGiven = NOT_GIVEN,
        task: str | NotGiven = NOT_GIVEN,
        temperature: Optional[float] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> WhisperResponse:  # type: ignore
        """
        Generate Audio Transcription

        Args:
            file:"<your base64 encoded audio byte data here>" OR "Path object of pathlib for the audio filepath"

            model_name: "openai/whisper-large-v3", # DO NOT CHANGE this

            task: "transcribe",

            language: "hindi", # Source language of the audio

            temperature: 0.0, # Optional, defaults to 0.0. Range - 0.0 to 2.0

            response_format: "json", # Optional, defaults to json. Values - verbose_json (or) json

            chunk_type: "word" # Optional, defaults to sentence. Values - sentence (or) word

            extra_headers: Send extra headers

            extra_query: Add additional query parameters to the request

            extra_body: Add additional JSON properties to the request

            timeout: Override the client-level default timeout for this request, in seconds
        """
        language = str(
            await self.validate_parameters(
                chunk_type=chunk_type,
                file=file,
                language=language,
                model_name=model_name,
                response_format=response_format,
                task=task,
                temperature=temperature,
                timeout=timeout,
            )
        )
        payload = {
            "chunk_type": chunk_type,
            "file": file,
            "language": language,
            "model_name": model_name,
            "response_format": response_format,
            "task": task,
            "temperature": temperature,
        }

        extra_options = {
            "extra_headers": extra_headers,
            "extra_query": extra_query,
            "extra_body": extra_body,
            "timeout": timeout,
        }
        tmp_filepath = None

        if isinstance(file, str):
            return await self._send_post_request(payload, extra_options)
        elif isinstance(file, Path) or isinstance(file, AudioSegment):
            try:
                if isinstance(file, Path):
                    audio_data = AudioSegment.from_file(file)  # type: ignore
                else:
                    audio_data = file  # type: ignore
                audio_data_duration: float = audio_data.duration_seconds  # type: ignore

                Path.mkdir(self.tmp_path, exist_ok=True)
                tmp_filepath = f"{self.tmp_path.as_posix()}{sep}{self.tmp_filename_prefix}.mp3"
                if audio_data_duration <= 120.0:  # Less then or equal to 2 minutes audio
                    with open(tmp_filepath, "wb") as file_object:
                        audio_data.export(file_object, format="mp3")  # type: ignore

                    audio_b64_data = convert_audio_file_to_base64(tmp_filepath)
                    payload["file"] = audio_b64_data
                    shutil.rmtree(self.tmp_path.as_posix())
                    return await self._send_post_request(payload, extra_options)
                else:
                    audio_data_chunks = audio_data[::120000]  # type: ignore # chunking with interval of 120 seconds
                    predictions: List[Dict[str, Any]] = []
                    for index, audio_data_chunk in enumerate(audio_data_chunks):  # type: ignore
                        tmp_filepath = f"{self.tmp_path.as_posix()}{sep}{self.tmp_filename_prefix}-{index}.mp3"
                        with open(tmp_filepath, "wb") as f:
                            audio_data_chunk.export(f, format="mp3")  # type: ignore

                        audio_b64_data = convert_audio_file_to_base64(tmp_filepath)
                        payload["file"] = audio_b64_data
                        predictions.append(self._send_post_request(payload, extra_options).predictions)  # type: ignore
                    shutil.rmtree(self.tmp_path.as_posix())
                    whisperResponse = WhisperResponse(predictions=None)
                    whisperResponse.predictions = await self._merge_predictions(predictions)
                    return whisperResponse
            except CouldntDecodeError as decode_error:
                if isinstance(file, Path):
                    raise CouldntDecodeError(
                        f"The file '{file.as_posix()}' is not a valid or supported audio file format.\n{decode_error}"
                    )
                else:
                    raise CouldntDecodeError(f"The file is not a valid or supported audio file format.\n{decode_error}")
            except FileNotFoundError as fnf_error:
                raise FileNotFoundError(f"Error: The file '{tmp_filepath}' was not found. {fnf_error}")

            except ValueError as val_error:
                raise ValueError(f"{val_error}")

            except Exception as exc:
                raise Exception(exc)


class TranscriptionsResourceWithRawResponse:
    def __init__(self, transcriptions: TranscriptionsResource) -> None:
        self._transcriptions = transcriptions

        self.create = to_raw_response_wrapper(
            transcriptions.create,
        )


class AsyncTranscriptionsResourceWithRawResponse:
    def __init__(self, transcriptions: AsyncTranscriptionsResource) -> None:
        self._transcriptions = transcriptions

        self.create = async_to_raw_response_wrapper(
            transcriptions.create,
        )


class TranscriptionsResourceWithStreamingResponse:
    def __init__(self, transcriptions: TranscriptionsResource) -> None:
        self._transcriptions = transcriptions

        self.create = to_streamed_response_wrapper(
            transcriptions.create,
        )


class AsyncTranscriptionsResourceWithStreamingResponse:
    def __init__(self, transcriptions: AsyncTranscriptionsResource) -> None:
        self._transcriptions = transcriptions

        self.create = async_to_streamed_response_wrapper(
            transcriptions.create,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx
import os
from typing import Optional

from ..._types import NOT_GIVEN, Body, Query, Headers, NoneType, NotGiven
from ..._utils import (
    maybe_transform,
    async_maybe_transform,
)
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ..._base_client import make_request_options
from ...types.deploy import task_list_params, task_create_params
from ...types.deploy.task_list_response import TaskListResponse
from ...types.deploy.task_create_response import TaskCreateResponse
from ...types.deploy.task_retrieve_response import TaskRetrieveResponse

__all__ = ["TasksResource", "AsyncTasksResource"]


class TasksResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> TasksResourceWithRawResponse:
        return TasksResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> TasksResourceWithStreamingResponse:
        return TasksResourceWithStreamingResponse(self)

    def _validate_create_parameters(
        self,
        bucket_name: str,
        model: str,
        version: str,
        s3_access_key: str,
        s3_endpoint: str,
        s3_region: str,
        s3_secret: str,
        argument: str | NotGiven = NOT_GIVEN,
        max_batch_size: Optional[int] = 256,
        max_replicas: Optional[int] = 1,
        min_replicas: Optional[int] = 1,
        environ: Optional[str] = "",
    ):
        # Validate bucket_name
        if bucket_name and not isinstance(bucket_name, str):
            raise TypeError("'bucket_name' must be of type string.")

        # Validate model
        if model and not isinstance(model, str):
            raise TypeError("'model' must be of type string.")

        # Validate version
        if version and not isinstance(version, str):
            raise TypeError("'version' must be of type string.")

        # Validate argument
        if argument and not isinstance(argument, str):
            raise TypeError("'argument' must be of type string.")

        # Validate max_batch_size
        if max_batch_size and not isinstance(max_batch_size, int):
            raise TypeError("'max_batch_size' must be of type integer.")

        # Validate max_replicas
        if max_replicas and not isinstance(max_replicas, int):
            raise TypeError("'max_replicas' must be of type integer.")

        # Validate min_replicas
        if min_replicas and not isinstance(min_replicas, int):
            raise TypeError("'min_replicas' must be of type integer.")

        # Validate s3_access_key
        if s3_access_key and not isinstance(s3_access_key, str):
            raise TypeError("'s3_access_key' must be of type string.")

        # Validate s3_endpoint
        if s3_endpoint and not isinstance(s3_endpoint, str):
            raise TypeError("'s3_endpoint' must be of type string.")

        # Validate s3_region
        if s3_region and not isinstance(s3_region, str):
            raise TypeError("'s3_region' must be of type string.")

        # Validate s3_secret
        if s3_secret and not isinstance(s3_secret, str):
            raise TypeError("'s3_secret' must be of type string.")

        # Validate environ
        if environ and not isinstance(environ, str):
            raise TypeError("'environ' must be of type string.")

    def _validate_retrieve_parameters(
        self,
        id: str,
    ):

        # Validate id
        if id and not isinstance(id, str):
            raise TypeError("'id' must be of type string.")

    def _validate_list_parameters(self, limit: int, offset: int):

        # Validate limit
        if limit and not isinstance(limit, int):
            raise TypeError("'limit' must be of type integer.")

        # Validate offset
        if offset and not isinstance(offset, int):
            raise TypeError("'offset' must be of type integer.")

    def _validate_cancel_parameters(
        self,
        id: str,
    ):

        # Validate id
        if id and not isinstance(id, str):
            raise TypeError("'id' must be of type string.")

    def create(
        self,
        *,
        bucket_name: str,
        version: str,
        argument: str | NotGiven = NOT_GIVEN,
        max_batch_size: int | NotGiven = NOT_GIVEN,
        max_replicas: int | NotGiven = NOT_GIVEN,
        min_replicas: int | NotGiven = NOT_GIVEN,
        model: str,
        s3_access_key: str,
        s3_endpoint: str,
        s3_region: str,
        s3_secret: str,
        environ: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> TaskCreateResponse:
        """
        Create inference task

        Args:
            bucket_name: Bucket name where model files got uploaded

            version: Version of model given while uploading the model to S3 bucket

            argument: additional argument to parse to inference engine

            max_batch_size: max batch size

            max_replicas: Max number of replicas

            min_replicas: Min number of replicas

            model: Model name.

            s3_access_key: S3 access key

            s3_endpoint: S3 endpoint

            s3_region: S3 region

            s3_secret: S3 secret

            environ: additional environment variables as "key_1=value1,key_2=value2" to pass to inference engine

            extra_headers: Send extra headers

            extra_query: Add additional query parameters to the request

            extra_body: Add additional JSON properties to the request

            timeout: Override the client-level default timeout for this request, in seconds
        """
        self._validate_create_parameters(
            bucket_name=bucket_name,
            version=version,
            argument=argument,
            max_batch_size=max_batch_size,
            max_replicas=max_replicas,
            min_replicas=min_replicas,
            model=model,
            s3_access_key=s3_access_key,
            s3_endpoint=s3_endpoint,
            s3_region=s3_region,
            s3_secret=s3_secret,
            environ=environ,
        )
        # Fetch Model ID from Model Card by given model name
        model_id = self._client.registry.model_registry.fetch_model_id(model_name=model)
        s3_path = f"s3://{bucket_name}/{model}/{version}"

        if os.environ.get("KRUTRIM_CLOUD_K_CUSTOMER_ID"):
            extra_headers = {"K-Customer-ID": os.environ.get("KRUTRIM_CLOUD_K_CUSTOMER_ID"), **(extra_headers or {})}
        response = self._post(
            "/api/v1/inference/tasks",
            body=maybe_transform(
                {
                    "argument": argument,
                    "max_batch_size": max_batch_size,
                    "max_replicas": max_replicas,
                    "min_replicas": min_replicas,
                    "model": model_id,
                    "path": s3_path,
                    "s3_access_key": s3_access_key,
                    "s3_endpoint": s3_endpoint,
                    "s3_region": s3_region,
                    "s3_secret": s3_secret,
                    "environ": environ,
                },
                task_create_params.TaskCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=TaskCreateResponse,
        )
        response.name = self._client.registry.model_registry.fetch_model_name(response.name)

        self._client.registry.model_registry.add_model_deployment_version(
            model_name=response.name, model_id=model_id, deploy_id=response.id, base_model=""
        )
        return response

    def retrieve(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> TaskRetrieveResponse:
        """
        Get inference task information.

        Args:
            id: Task ID

            extra_headers: Send extra headers

            extra_query: Add additional query parameters to the request

            extra_body: Add additional JSON properties to the request

            timeout: Override the client-level default timeout for this request, in seconds
        """
        self._validate_retrieve_parameters(id=id)
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        if os.environ.get("KRUTRIM_CLOUD_K_CUSTOMER_ID"):
            extra_headers = {"K-Customer-ID": os.environ.get("KRUTRIM_CLOUD_K_CUSTOMER_ID"), **(extra_headers or {})}
        response = self._get(
            f"/api/v1/inference/tasks/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=TaskRetrieveResponse,
        )
        response.name = self._client.registry.model_registry.fetch_model_name(response.name)
        return response

    def list(
        self,
        *,
        limit: int | NotGiven = NOT_GIVEN,
        offset: int | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> TaskListResponse:
        """
        List inference tasks

        Args:
            limit: Limit the max number of item to be return.

            offset: Offset index.

            extra_headers: Send extra headers

            extra_query: Add additional query parameters to the request

            extra_body: Add additional JSON properties to the request

            timeout: Override the client-level default timeout for this request, in seconds
        """
        self._validate_list_parameters(limit=limit, offset=offset)

        if os.environ.get("KRUTRIM_CLOUD_K_CUSTOMER_ID"):
            extra_headers = {"K-Customer-ID": os.environ.get("KRUTRIM_CLOUD_K_CUSTOMER_ID"), **(extra_headers or {})}
        response = self._get(
            "/api/v1/inference/tasks",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "limit": limit,
                        "offset": offset,
                    },
                    task_list_params.TaskListParams,
                ),
            ),
            cast_to=TaskListResponse,
        )
        for task_obj in response.task_list:
            task_obj["name"] = self._client.registry.model_registry.fetch_model_name(task_obj["name"])
        return response

    def cancel(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Cancel inference task.

        Args:

            id: Task ID

            extra_headers: Send extra headers

            extra_query: Add additional query parameters to the request

            extra_body: Add additional JSON properties to the request

            timeout: Override the client-level default timeout for this request, in seconds
        """
        self._validate_cancel_parameters(id=id)
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        if os.environ.get("KRUTRIM_CLOUD_K_CUSTOMER_ID"):
            extra_headers = {"K-Customer-ID": os.environ.get("KRUTRIM_CLOUD_K_CUSTOMER_ID"), **(extra_headers or {})}
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._get(
            f"/api/v1/inference/tasks/{id}/cancel",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class AsyncTasksResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncTasksResourceWithRawResponse:
        return AsyncTasksResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncTasksResourceWithStreamingResponse:
        return AsyncTasksResourceWithStreamingResponse(self)

    async def _validate_create_parameters(
        self,
        model: str,
        s3_access_key: str,
        s3_endpoint: str,
        s3_region: str,
        s3_secret: str,
        argument: str | NotGiven = NOT_GIVEN,
        max_batch_size: Optional[int] = 256,
        max_replicas: Optional[int] = 1,
        min_replicas: Optional[int] = 1,
        environ: Optional[str] = "",
    ):

        # Validate model
        if model and not isinstance(model, str):
            raise TypeError("'model' must be of type string.")

        # Validate path
        if path and not isinstance(path, str):
            raise TypeError("'path' must be of type string.")
        if path and not path.lower().startswith("s3://"):
            raise TypeError("'path' must start with S3:// or s3://")

        # Validate argument
        if argument and not isinstance(argument, str):
            raise TypeError("'argument' must be of type string.")

        # Validate checkpoint
        if checkpoint and not isinstance(checkpoint, str):
            raise TypeError("'checkpoint' must be of type string.")

        # Validate max_batch_size
        if max_batch_size and not isinstance(max_batch_size, int):
            raise TypeError("'max_batch_size' must be of type integer.")

        # Validate max_replicas
        if max_replicas and not isinstance(max_replicas, int):
            raise TypeError("'max_replicas' must be of type integer.")

        # Validate min_replicas
        if min_replicas and not isinstance(min_replicas, int):
            raise TypeError("'min_replicas' must be of type integer.")

        # Validate namespace
        if namespace and not isinstance(namespace, str):
            raise TypeError("'namespace' must be of type string.")

        # Validate priority
        if priority and not isinstance(priority, int):
            raise TypeError("'priority' must be of type integer.")

        # Validate region
        if region and not isinstance(region, str):
            raise TypeError("'region' must be of type string.")

        # Validate s3_access_key
        if s3_access_key and not isinstance(s3_access_key, str):
            raise TypeError("'s3_access_key' must be of type string.")

        # Validate s3_endpoint
        if s3_endpoint and not isinstance(s3_endpoint, str):
            raise TypeError("'s3_endpoint' must be of type string.")

        # Validate s3_region
        if s3_region and not isinstance(s3_region, str):
            raise TypeError("'s3_region' must be of type string.")

        # Validate s3_secret
        if s3_secret and not isinstance(s3_secret, str):
            raise TypeError("'s3_secret' must be of type string.")

        # Validate environ
        if environ and not isinstance(environ, str):
            raise TypeError("'environ' must be of type string.")

    async def _validate_retrieve_parameters(
        self,
        id: str,
    ):

        # Validate id
        if id and not isinstance(id, str):
            raise TypeError("'id' must be of type string.")

    async def _validate_list_parameters(self, limit: int, offset: int):

        # Validate limit
        if limit and not isinstance(limit, int):
            raise TypeError("'limit' must be of type integer.")

        # Validate offset
        if offset and not isinstance(offset, int):
            raise TypeError("'offset' must be of type integer.")

    async def _validate_cancel_parameters(
        self,
        id: str,
    ):

        # Validate id
        if id and not isinstance(id, str):
            raise TypeError("'id' must be of type string.")

    async def create(
        self,
        *,
        argument: str | NotGiven = NOT_GIVEN,
        max_batch_size: int | NotGiven = NOT_GIVEN,
        max_replicas: int | NotGiven = NOT_GIVEN,
        min_replicas: int | NotGiven = NOT_GIVEN,
        model: str,
        s3_access_key: str,
        s3_endpoint: str,
        s3_region: str,
        s3_secret: str,
        environ: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> TaskCreateResponse:
        """
        Create inference task

        Args:
            argument: additional argument to parse to inference engine

            max_batch_size: max batch size

            max_replicas: Max number of replicas

            min_replicas: Min number of replicas

            model: Model name.

            s3_access_key: S3 access key

            s3_endpoint: S3 endpoint

            s3_region: S3 region

            s3_secret: S3 secret

            environ: additional environment variables as "key_1=value1,key_2=value2" to pass to inference engine

            extra_headers: Send extra headers

            extra_query: Add additional query parameters to the request

            extra_body: Add additional JSON properties to the request

            timeout: Override the client-level default timeout for this request, in seconds
        """
        await self._validate_create_parameters(
            argument=argument,
            max_batch_size=max_batch_size,
            max_replicas=max_replicas,
            min_replicas=min_replicas,
            model=model,
            s3_access_key=s3_access_key,
            s3_endpoint=s3_endpoint,
            s3_region=s3_region,
            s3_secret=s3_secret,
            environ=environ,
        )

        if os.environ.get("KRUTRIM_CLOUD_K_CUSTOMER_ID"):
            extra_headers = {"K-Customer-ID": os.environ.get("KRUTRIM_CLOUD_K_CUSTOMER_ID"), **(extra_headers or {})}
        return await self._post(
            "/api/v1/inference/tasks",
            body=await async_maybe_transform(
                {
                    "argument": argument,
                    "max_batch_size": max_batch_size,
                    "max_replicas": max_replicas,
                    "min_replicas": min_replicas,
                    "model": model,
                    "s3_access_key": s3_access_key,
                    "s3_endpoint": s3_endpoint,
                    "s3_region": s3_region,
                    "s3_secret": s3_secret,
                    "environ": environ,
                },
                task_create_params.TaskCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=TaskCreateResponse,
        )

    async def retrieve(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> TaskRetrieveResponse:
        """
        Get inference task information.

        Args:
            extra_headers: Send extra headers

            extra_query: Add additional query parameters to the request

            extra_body: Add additional JSON properties to the request

            timeout: Override the client-level default timeout for this request, in seconds
        """
        await self._validate_retrieve_parameters(id=id)

        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        if os.environ.get("KRUTRIM_CLOUD_K_CUSTOMER_ID"):
            extra_headers = {"K-Customer-ID": os.environ.get("KRUTRIM_CLOUD_K_CUSTOMER_ID"), **(extra_headers or {})}
        return await self._get(
            f"/api/v1/inference/tasks/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=TaskRetrieveResponse,
        )

    async def list(
        self,
        *,
        limit: int | NotGiven = NOT_GIVEN,
        offset: int | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> TaskListResponse:
        """
        List inference tasks

        Args:
            limit: Limit the max number of item to be return.

            offset: Offset index.

            extra_headers: Send extra headers

            extra_query: Add additional query parameters to the request

            extra_body: Add additional JSON properties to the request

            timeout: Override the client-level default timeout for this request, in seconds
        """
        await self._validate_list_parameters(limit=limit, offset=offset)

        if os.environ.get("KRUTRIM_CLOUD_K_CUSTOMER_ID"):
            extra_headers = {"K-Customer-ID": os.environ.get("KRUTRIM_CLOUD_K_CUSTOMER_ID"), **(extra_headers or {})}
        return await self._get(
            "/api/v1/inference/tasks",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {
                        "limit": limit,
                        "offset": offset,
                    },
                    task_list_params.TaskListParams,
                ),
            ),
            cast_to=TaskListResponse,
        )

    async def cancel(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Cancel inference task.

        Args:
            extra_headers: Send extra headers

            extra_query: Add additional query parameters to the request

            extra_body: Add additional JSON properties to the request

            timeout: Override the client-level default timeout for this request, in seconds
        """
        await self._validate_cancel_parameters(id=id)
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        if os.environ.get("KRUTRIM_CLOUD_K_CUSTOMER_ID"):
            extra_headers = {"K-Customer-ID": os.environ.get("KRUTRIM_CLOUD_K_CUSTOMER_ID"), **(extra_headers or {})}
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._get(
            f"/api/v1/inference/tasks/{id}/cancel",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class TasksResourceWithRawResponse:
    def __init__(self, tasks: TasksResource) -> None:
        self._tasks = tasks

        self.create = to_raw_response_wrapper(
            tasks.create,
        )
        self.retrieve = to_raw_response_wrapper(
            tasks.retrieve,
        )
        self.list = to_raw_response_wrapper(
            tasks.list,
        )
        self.cancel = to_raw_response_wrapper(
            tasks.cancel,
        )


class AsyncTasksResourceWithRawResponse:
    def __init__(self, tasks: AsyncTasksResource) -> None:
        self._tasks = tasks

        self.create = async_to_raw_response_wrapper(
            tasks.create,
        )
        self.retrieve = async_to_raw_response_wrapper(
            tasks.retrieve,
        )
        self.list = async_to_raw_response_wrapper(
            tasks.list,
        )
        self.cancel = async_to_raw_response_wrapper(
            tasks.cancel,
        )


class TasksResourceWithStreamingResponse:
    def __init__(self, tasks: TasksResource) -> None:
        self._tasks = tasks

        self.create = to_streamed_response_wrapper(
            tasks.create,
        )
        self.retrieve = to_streamed_response_wrapper(
            tasks.retrieve,
        )
        self.list = to_streamed_response_wrapper(
            tasks.list,
        )
        self.cancel = to_streamed_response_wrapper(
            tasks.cancel,
        )


class AsyncTasksResourceWithStreamingResponse:
    def __init__(self, tasks: AsyncTasksResource) -> None:
        self._tasks = tasks

        self.create = async_to_streamed_response_wrapper(
            tasks.create,
        )
        self.retrieve = async_to_streamed_response_wrapper(
            tasks.retrieve,
        )
        self.list = async_to_streamed_response_wrapper(
            tasks.list,
        )
        self.cancel = async_to_streamed_response_wrapper(
            tasks.cancel,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from ...._compat import cached_property
from .text2video import (
    Text2videoResource,
    AsyncText2videoResource,
    Text2videoResourceWithRawResponse,
    AsyncText2videoResourceWithRawResponse,
    Text2videoResourceWithStreamingResponse,
    AsyncText2videoResourceWithStreamingResponse,
)
from ...._resource import SyncAPIResource, AsyncAPIResource

__all__ = ["GenerationsResource", "AsyncGenerationsResource"]


class GenerationsResource(SyncAPIResource):
    @cached_property
    def text2video(self) -> Text2videoResource:
        return Text2videoResource(self._client)

    @cached_property
    def with_raw_response(self) -> GenerationsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return the
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/stainless-sdks/cogvideo-python#accessing-raw-response-data-eg-headers
        """
        return GenerationsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> GenerationsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/stainless-sdks/cogvideo-python#with_streaming_response
        """
        return GenerationsResourceWithStreamingResponse(self)


class AsyncGenerationsResource(AsyncAPIResource):
    @cached_property
    def text2video(self) -> AsyncText2videoResource:
        return AsyncText2videoResource(self._client)

    @cached_property
    def with_raw_response(self) -> AsyncGenerationsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return the
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/stainless-sdks/cogvideo-python#accessing-raw-response-data-eg-headers
        """
        return AsyncGenerationsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncGenerationsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/stainless-sdks/cogvideo-python#with_streaming_response
        """
        return AsyncGenerationsResourceWithStreamingResponse(self)


class GenerationsResourceWithRawResponse:
    def __init__(self, generations: GenerationsResource) -> None:
        self._generations = generations

    @cached_property
    def text2video(self) -> Text2videoResourceWithRawResponse:
        return Text2videoResourceWithRawResponse(self._generations.text2video)


class AsyncGenerationsResourceWithRawResponse:
    def __init__(self, generations: AsyncGenerationsResource) -> None:
        self._generations = generations

    @cached_property
    def text2video(self) -> AsyncText2videoResourceWithRawResponse:
        return AsyncText2videoResourceWithRawResponse(self._generations.text2video)


class GenerationsResourceWithStreamingResponse:
    def __init__(self, generations: GenerationsResource) -> None:
        self._generations = generations

    @cached_property
    def text2video(self) -> Text2videoResourceWithStreamingResponse:
        return Text2videoResourceWithStreamingResponse(self._generations.text2video)


class AsyncGenerationsResourceWithStreamingResponse:
    def __init__(self, generations: AsyncGenerationsResource) -> None:
        self._generations = generations

    @cached_property
    def text2video(self) -> AsyncText2videoResourceWithStreamingResponse:
        return AsyncText2videoResourceWithStreamingResponse(self._generations.text2video)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .idefics_response import IdeficsResponse as IdeficsResponse
from .generation_idefics_params import GenerationIdeficsParams as GenerationIdeficsParams



from enum import Enum
import json
import os
from krutrim_cloud.lib.prompts import prompts
from pathlib import Path
from typing import Dict


class Category(Enum):
    """Enumeration for prompt categories."""

    CREATIVE_WRITING = "Creative Writing"
    CUSTOMER_SUPPORT = "Customer Support"
    TECHNICAL_SUPPORT = "Technical Support"
    MARKETING_AND_SALES = "Marketing and Sales"
    PRODUCT_DEVELOPMENT = "Product Development"
    EDUCATION_AND_TRAINING = "Education and Training"
    RESEARCH_AND_ANALYSIS = "Research and Analysis"
    SOCIAL_MEDIA_MANAGEMENT = "Social Media Management"
    HEALTH_AND_WELLNESS = "Health and Wellness"
    LEGAL_AND_COMPLIANCE = "Legal and Compliance"
    HUMAN_RESOURCES = "Human Resources"
    FINANCE_AND_ACCOUNTING = "Finance and Accounting"
    SOFTWARE_DEVELOPMENT = "Software Development"
    GAMING_AND_ENTERTAINMENT = "Gaming and Entertainment"
    GENERAL_KNOWLEDGE = "General Knowledge"


class PromptRegistryError(Exception):
    """Custom exception for PromptRegistry errors."""

    pass


class PromptRegistry:
    def __init__(self) -> None:
        self.registry: Dict[str, str] = {}
        try:
            self.load_prompts()
        except Exception as e:
            raise PromptRegistryError(f"Failed to load default prompts: {e}")

    def load_prompts(self):
        """Load default prompts."""
        self.registry = prompts

    def load_prompts_from_file(self, filepath: str):
        """Load prompts from a JSON file."""
        if not os.path.exists(filepath):
            raise FileNotFoundError(f"Prompt file '{filepath}' not found.")
        else:
            try:
                with open(filepath, "r") as file:
                    self.registry = json.load(file)
            except json.JSONDecodeError as e:
                raise PromptRegistryError(f"Error decoding JSON from '{filepath}': {e}")
            except Exception as e:
                raise PromptRegistryError(f"An error occurred while loading prompts from '{filepath}': {e}")

    def save_prompts_to_file(self, output_filepath: str):
        """Save prompts to a JSON file."""
        try:
            Path.mkdir(Path(output_filepath).parent, exist_ok=True)
            with open(output_filepath, "w") as file:
                json.dump(self.registry, file, indent=4)
        except Exception as e:
            raise PromptRegistryError(f"Failed to save prompts to '{output_filepath}': {e}")

    def get_prompt(self, category: Category):
        """Retrieve the prompt under a specific category."""
        try:
            return self.registry[category.value]
        except KeyError:
            raise PromptRegistryError(f"Category '{category.value}' not found in the registry.")

    def list_categories(self):
        """List all available categories."""
        try:
            return [category.name for category in Category]
        except Exception as e:
            raise PromptRegistryError(f"An error occurred while listing categories: {e}")

    def update_prompt(self, category: Category, prompt: str, output_filepath: str = ""):
        """Update the prompt of a specific category."""
        try:
            self.registry[category.value] = prompt
            if output_filepath:
                self.save_prompts_to_file(output_filepath)
        except Exception as e:
            raise PromptRegistryError(f"Failed to update prompt for category '{category.value}': {e}")

    def search_prompts(self, keyword: str):
        """Search for prompts containing a specific keyword."""
        try:
            """Search for prompts containing a specific keyword."""
            results = {
                category: prompt for category, prompt in self.registry.items() if keyword.lower() in prompt.lower()
            }
            return results
        except Exception as e:
            raise PromptRegistryError(f"An error occurred while searching for prompts with keyword '{keyword}': {e}")



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .multimodal import (
    MultimodalResource,
    AsyncMultimodalResource,
    MultimodalResourceWithRawResponse,
    AsyncMultimodalResourceWithRawResponse,
    MultimodalResourceWithStreamingResponse,
    AsyncMultimodalResourceWithStreamingResponse,
)
from .generations import (
    GenerationsResource,
    AsyncGenerationsResource,
    GenerationsResourceWithRawResponse,
    AsyncGenerationsResourceWithRawResponse,
    GenerationsResourceWithStreamingResponse,
    AsyncGenerationsResourceWithStreamingResponse,
)

__all__ = [
    "GenerationsResource",
    "AsyncGenerationsResource",
    "GenerationsResourceWithRawResponse",
    "AsyncGenerationsResourceWithRawResponse",
    "GenerationsResourceWithStreamingResponse",
    "AsyncGenerationsResourceWithStreamingResponse",
    "MultimodalResource",
    "AsyncMultimodalResource",
    "MultimodalResourceWithRawResponse",
    "AsyncMultimodalResourceWithRawResponse",
    "MultimodalResourceWithStreamingResponse",
    "AsyncMultimodalResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import TypedDict


__all__ = ["TaskListParams"]


class TaskListParams(TypedDict, total=False):

    limit: int
    """Limit the max number of item to be return."""

    offset: int
    """Offset index."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .task_list_params import TaskListParams as TaskListParams
from .task_create_params import TaskCreateParams as TaskCreateParams
from .task_list_response import TaskListResponse as TaskListResponse
from .task_create_response import TaskCreateResponse as TaskCreateResponse
from .task_retrieve_response import TaskRetrieveResponse as TaskRetrieveResponse



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .stable_diffusion_response import StableDiffusionResponse as StableDiffusionResponse
from .generation_diffusion_params import GenerationDiffusionParams as GenerationDiffusionParams



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from .generations import (
    GenerationsResource,
    AsyncGenerationsResource,
    GenerationsResourceWithRawResponse,
    AsyncGenerationsResourceWithRawResponse,
    GenerationsResourceWithStreamingResponse,
    AsyncGenerationsResourceWithStreamingResponse,
)

__all__ = ["ImagesResource", "AsyncImagesResource"]


class ImagesResource(SyncAPIResource):
    @cached_property
    def generations(self) -> GenerationsResource:
        return GenerationsResource(self._client)

    @cached_property
    def with_raw_response(self) -> ImagesResourceWithRawResponse:
        return ImagesResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> ImagesResourceWithStreamingResponse:
        return ImagesResourceWithStreamingResponse(self)


class AsyncImagesResource(AsyncAPIResource):
    @cached_property
    def generations(self) -> AsyncGenerationsResource:
        return AsyncGenerationsResource(self._client)

    @cached_property
    def with_raw_response(self) -> AsyncImagesResourceWithRawResponse:
        return AsyncImagesResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncImagesResourceWithStreamingResponse:
        return AsyncImagesResourceWithStreamingResponse(self)


class ImagesResourceWithRawResponse:
    def __init__(self, images: ImagesResource) -> None:
        self._images = images

    @cached_property
    def generations(self) -> GenerationsResourceWithRawResponse:
        return GenerationsResourceWithRawResponse(self._images.generations)


class AsyncImagesResourceWithRawResponse:
    def __init__(self, images: AsyncImagesResource) -> None:
        self._images = images

    @cached_property
    def generations(self) -> AsyncGenerationsResourceWithRawResponse:
        return AsyncGenerationsResourceWithRawResponse(self._images.generations)


class ImagesResourceWithStreamingResponse:
    def __init__(self, images: ImagesResource) -> None:
        self._images = images

    @cached_property
    def generations(self) -> GenerationsResourceWithStreamingResponse:
        return GenerationsResourceWithStreamingResponse(self._images.generations)


class AsyncImagesResourceWithStreamingResponse:
    def __init__(self, images: AsyncImagesResource) -> None:
        self._images = images

    @cached_property
    def generations(self) -> AsyncGenerationsResourceWithStreamingResponse:
        return AsyncGenerationsResourceWithStreamingResponse(self._images.generations)
